<?php
// Exit if accessed directly
if (!defined('ABSPATH')) { exit; }
if (!class_exists('SHIRTEE_IMPORTER')) {
    class SHIRTEE_IMPORTER
    {
        /**
         * Holds a copy of itself, so it can be referenced by the class name.
         *
         * @since 3.5
         *
         * @var SHIRTEE_IMPORTER
         */
        public static $instance;
        /**
         * Holds arrays of plugin pages.
         *
         * @since 3.10
         *
         * @var array
         */
        private $_shirtee_pages = array("dashboard","shirtee-products","shirtee-create-products","shirtee-orders","add-settings","help-guide");
        /**
         * Calls when object of class is created.
         *
         * @see SHIRTEE_IMPORTER::init()
         *
         * @since 3.5
         */
        public function __construct()
        {
            $this->init();            
            if( isset($_GET['activation_code']) && !empty($_GET['activation_code'])) {
                $active_email = isset($_GET['activation_code']) && !empty($_GET['activation_code']) ? $_GET['activation_code'] : '';
                $res_data = $this->execute_curl($active_email, "confirm_email");
                if($res_data != null){
                    if($res_data['status'] == 'success'){                       
                        global $wpdb;
                        $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                        $wpdb->update(
                            $tbl_settings,
                            array(
                                "settings_value" => "active"
                            ),
                            array(
                                "settings_name"  => "shirtee_register"
                            )
                        );
                        $this->complete_registration_process($res_data);                        
                        echo $this->welcome_template($res_data); 
                        $site_url =  get_home_url();
                        $longurl = $site_url.'/wp-admin/admin.php?page=add-settings'; 
                        ?>
                        <script type='text/javascript'>
                                setTimeout(function () {
                                    window.location = "<?php echo $longurl; ?>";
                                }, 5000);
                        </script>
                        <?php exit();
                    } else {                    
                        echo $this->welcome_template($res_data);
                        exit();
                    }                
                }
            }
             
        }
        /**
         * Returns the singleton instance of the class.
         *
         * @since 3.5
         *
         * @return \SHIRTEE_IMPORTER The SHIRTEE_IMPORTER object.
         */
        public static function get_instance()
        {
            if (!isset(self::$instance) && !(self::$instance instanceof self)) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        /**
         * Call when object of class created.
         */
        public function init()
        {
            /**
             * Activate plugin and register activation file of plugin with Wordpress
             */

            $plugin_path = plugin_dir_path(dirname(__FILE__, 2));

            if (!defined('SHIRTEE_ROOT_DIR')) 
            {
              define('SHIRTEE_ROOT_DIR', $plugin_path);
            }

            register_activation_hook(SHIRTEE_ROOT_DIR.'/functions.php', array($this, 'shirtee_product_install'));
            
            add_filter('plugin_action_links_'.plugin_basename(SHIRTEE_ROOT_DIR.'/functions.php'), array($this, 'add_action_links'));
            //add_action('init', array($this, 'shirtee_language_load_textdomain'));
            /*Add ADMIN Hooks*/
            if (is_admin()) {
                include_once(SHIRTEE_ROOT_DIR.'/includes/tgm-plugin-activation/tgm-init.php');              
            }
            /*Redirect to guidance page after fresh install*/
            add_action('admin_head', array($this, 'shirtee_init'));
            add_action('admin_menu', array($this, 'shirtee_admin_menu'));
            add_action('admin_init', array($this, 'shirtee_plugin_redirect'));
            /* Register Scripts */
            add_action('admin_enqueue_scripts', array($this, 'shirtee_enqueue_scripts'));
            /*Check for remove woo id from shirtee products data*/
            add_action('before_delete_post', array($this, 'shirtee_product_delete'));
            /* Register AJAX Handlers */
            /* Login TO Shirtee*/
            add_action('wp_ajax_login_to_shirtee', array($this, 'login_to_shirtee'));
            // add_action('wp_ajax_nopriv_login_to_shirtee', array($this, 'login_to_shirtee'));
            /* Login TO Shirtee API*/
            add_action('wp_ajax_login_to_shirtee_api', array($this, "login_to_shirtee_api"));
            // add_action('wp_ajax_nopriv_login_to_shirtee_api', array($this, "login_to_shirtee_api"));
            /* Resend email */
            add_action('wp_ajax_email_resend', array($this, "email_resend"));
            // add_action('wp_ajax_nopriv_email_resend', array($this, "email_resend"));
            /* Change Registration */
            add_action('wp_ajax_change_registration', array($this, "change_registration"));
            // add_action('wp_ajax_nopriv_change_registration', array($this, "change_registration"));
            /* Fetch Data */
            add_action("wp_ajax_fetch_data", array($this, "fetch_data"));
            // add_action("wp_ajax_nopriv_fetch_data", array($this, "fetch_data"));
            /* Schedule product for insert/update */
            add_action('wp_ajax_woo_product_schedule_process', array($this, 'woo_product_schedule_process'));
            // add_action('wp_ajax_nopriv_woo_product_schedule_process', array($this, 'woo_product_schedule_process'));
            /*Product List*/
            add_action('wp_ajax_products_list', array($this, 'products_list'));
            // add_action('wp_ajax_nopriv_products_list', array($this, 'products_list'));
            /*Order Listing*/
            add_action('wp_ajax_order_list', array($this, 'order_list'));
            // add_action('wp_ajax_nopriv_order_list', array($this, 'order_list'));
            /* Remove Shirtee product from listing */
            add_action('wp_ajax_woo_remove_shirtee_product', array($this, 'woo_remove_shirtee_product'));
            // add_action('wp_ajax_nopriv_woo_remove_shirtee_product', array($this, 'woo_remove_shirtee_product'));

            /* Woo Orders to Shirtee Cron */
            add_action('woocommerce_order_status_changed', array($this, 'manage_order_to_magento'));
            add_action('woocommerce_payment_complete', array($this, 'manage_order_to_magento'));

            //check table column if not available then add
            global $wpdb;
            $simpleData = "{$wpdb->prefix}shirtee_import_products";
            $product_attributesrow = $wpdb->get_results("SHOW COLUMNS FROM ".$simpleData." LIKE 'product_attributes_new'");
            if( empty($product_attributesrow) ){
                $wpdb->query("ALTER TABLE ".$simpleData." ADD product_attributes_new TEXT NULL");
            }
            $is_all_importrow = $wpdb->get_results("SHOW COLUMNS FROM ".$simpleData." LIKE 'is_all_import'");
            if( empty($is_all_importrow) ){
                $wpdb->query("ALTER TABLE ".$simpleData." ADD is_all_import int(11) NULL DEFAULT 0");
            }
            $is_warehouserow = $wpdb->get_results("SHOW COLUMNS FROM ".$simpleData." LIKE 'is_warehouse'");
            if( empty($is_warehouserow) ){
                $wpdb->query("ALTER TABLE ".$simpleData." ADD is_warehouse int(11) NULL DEFAULT 0");
            }
            $ean_sku = $wpdb->get_results("SHOW COLUMNS FROM ".$simpleData." LIKE 'ean_sku'");
            if( empty($ean_sku) ){
                $wpdb->query("ALTER TABLE ".$simpleData." ADD ean_sku VARCHAR(100) NULL");
            }
            //check table column if not available then add end
            
            /**
             * Enqueue Front-end scripts
             */
            add_action('wp_enqueue_scripts', array($this, 'shirtee_frontend_enqueue_scripts'));
        }       
        public function shirtee_product_install()
        {
            global $wpdb;
            $simpleData = "{$wpdb->prefix}shirtee_import_products";
            $croninsert = "{$wpdb->prefix}shirtee_import_product_insert_cron";
            $orders     = "{$wpdb->prefix}shirtee_import_woo_orders";
            $settings   = "{$wpdb->prefix}shirtee_import_settings";
            $create_simple_data = "CREATE TABLE IF NOT EXISTS {$simpleData} (
                `ID`                 INT(11) NOT NULL AUTO_INCREMENT,
                `product_mage_id`    INT(11) NOT NULL,
                `product_woo_id`     INT(11) NULL DEFAULT 0,
                `product_title`      VARCHAR(250) NULL,
                `product_type`       VARCHAR(250) NULL,
                `product_sku`        VARCHAR(100) NULL,
                `ean_sku`            VARCHAR(100) NULL,
                `product_data`       TEXT NULL,
                `product_attributes` TEXT NULL,
                `product_attributes_new` TEXT NULL,
                `product_images`     TEXT NULL,
                `product_price`      int(11) NULL DEFAULT 0,
                `product_variations` int(11) NULL DEFAULT 0,
                `is_all_import`      int(11) NULL DEFAULT 0,
                `is_warehouse`       int(11) NULL DEFAULT 0,    
                `status`             int(2) NULL DEFAULT 0,
                PRIMARY KEY (`ID`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1";
            $create_insert_cron = "CREATE TABLE IF NOT EXISTS {$croninsert} (
                `ID`             INT(11) NOT NULL AUTO_INCREMENT,
                `uid`            INT(11) NULL,
                `mage_id`        VARCHAR(30),
                `woo_id`         INT(11),
                `product_status` VARCHAR(20) NOT NULL,
                `publish`        INT(1) NULL DEFAULT 0,
                `created_at`     DATETIME NULL,
                `updated_at`     DATETIME NULL,
                `status`         INT(11) NOT NULL DEFAULT 0,
                PRIMARY KEY (`ID`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1";
            $create_settings = "CREATE TABLE IF NOT EXISTS {$settings} (
                `ID`             INT(11) NOT NULL AUTO_INCREMENT,
                `settings_name`  VARCHAR(30) NOT NULL,
                `settings_value` TEXT NOT NULL,
                PRIMARY KEY (`ID`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1";
            $create_orders  = "CREATE TABLE IF NOT EXISTS {$orders} (
                `ID`                INT(11) NOT NULL AUTO_INCREMENT,
                `woo_order_ID`      INT(11) NOT NULL,
                `woo_order_data`    TEXT NOT NULL,
                `woo_order_email`   VARCHAR(255) NOT NULL,
                `woo_order_price`   FLOAT NOT NULL,
                `woo_order_status`  VARCHAR(20) NOT NULL,
                `woo_shirtee_id`    TEXT NOT NULL,
                `woo_shirtee_error` TEXT NOT NULL,
                `woo_order_date`    DATETIME NOT NULL,
                `status`            INT(2) DEFAULT 0 NOT NULL,
                PRIMARY KEY (`ID`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1";

            require_once(ABSPATH.'wp-admin/includes/upgrade.php');
            dbDelta($create_simple_data);
            dbDelta($create_insert_cron);
            dbDelta($create_settings);
            dbDelta($create_orders);
            if (get_option('shirtee_redirect_to_help', false) == '') {
                add_option('shirtee_redirect_to_help', 0, true);
            }
        }

        public function add_action_links($links)
        {
            $mylinks = array(
                '<a href="'.admin_url('admin.php?page=add-settings').'">Settings</a>',
            );
            return array_merge($mylinks, $links);
        }

        public static function is_shirtee_plugin_activate()
        {
            if (!function_exists('is_plugin_active')) {
                include_once ABSPATH.'wp-admin/includes/plugin.php';
            }
            if (!is_plugin_active('shirtee-products-1/functions.php')) {
                return false;
            }
            return true;
        }
        
        public static function is_shirtee_required_plugin_activate()
        {
            if (!function_exists('is_plugin_active')) {
                include_once ABSPATH.'wp-admin/includes/plugin.php';
            }
            if (!is_plugin_active('woocommerce/woocommerce.php')) {
                return false;
            }
            return true;
        }

        public function shirtee_init()
        {
            $page = isset($_GET['page']) && !empty($_GET['page']) ? $_GET['page'] : '';
            if (!empty($page) && in_array($page, $this->_shirtee_pages)) {
                if (!empty($settings = $this->shirtee_settings())) {
                    if (isset($settings['username']) && !empty($settings['username']) && isset($settings['password']) && !empty($settings['password']) && isset($settings['catID']) && !empty($settings['catID']) && isset($settings['email']) && !empty($settings['email'])) {
                        if ($this->check_designer()) {
                            if (!get_option('shirtee_popup_show', false)) {
                                update_option('shirtee_popup_show', 1, false);
                                echo $this->display_popup();
                            }
                        } else {
                            $this->shirtee_register_designer();
                        }
                    }
                }
            }
            
        }

        public function check_designer()
        {
            $designerIsRegister = 0;
            $access_token       = $this->shirtee_settings('access_token');
            if (!empty($access_token)) {
                $designerIsRegister = 1;
            }
            return $designerIsRegister;
        }

        public function is_migrated()
        {
            $is_migrated = $this->shirtee_settings('is_migrated');
            return $is_migrated;
        }

        public function shirtee_register_designer()
        {
            global $wpdb;
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
            $settings     = $this->shirtee_settings();
            if (empty($settings)) {
                return false;
            }
            $is_old = $this->check_availability();
            $data = array(
                "site_url"  => site_url(),
                "site_name" => get_option("blogname"),
                "type"      => SHIRTEE_APP,
                "is_old"    => $is_old,
            );
            $res_data = $this->execute_curl($data, 'designer_details');
            if ($res_data['status'] == 'success' && isset($res_data['msg'])) {
                if (isset($res_data['designer_details'])) {
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            'settings_value' => serialize($res_data['designer_details'])
                        ),
                        array(
                            'settings_name'  => 'import_settings'
                        )
                    );
                }
                $access_token = $this->shirtee_settings('access_token');
                if (!empty($access_token)) {
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            'settings_value' => $res_data['msg']
                        ),
                        array(
                            'settings_name'  => 'access_token'
                        )
                    );
                } else {
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            'settings_name'  => 'access_token',
                            'settings_value' => $res_data['msg']
                        )
                    );
                }
                if ($is_old) {
                    $is_migrated = $this->shirtee_settings('is_migrated');
                    if (!empty($is_migrated)) {
                        $wpdb->update(
                            $tbl_settings,
                            array(
                                'settings_value' => 'no'
                            ),
                            array(
                                'settings_name'  => 'is_migrated'
                            )
                        );
                    } else {
                        $wpdb->insert(
                            $tbl_settings,
                            array(
                                'settings_name'  => 'is_migrated',
                                'settings_value' => 'no'
                            )
                        );
                    }
                }
                $page = isset($_GET['page']) && !empty($_GET['page']) ? $_GET['page'] : '';
                exit(wp_safe_redirect(admin_url("admin.php?page={$page}")));
            }
        }

        public function check_availability()
        {
            global $wpdb;
            $tbl_products  = "{$wpdb->prefix}shirtee_import_products";
            $tbl_orders    = "{$wpdb->prefix}shirtee_import_woo_orders";
            $check_product = $wpdb->query("SELECT ID FROM {$tbl_products}");
            $check_order   = $wpdb->query("SELECT ID FROM {$tbl_orders}");
            if ($check_product > 0 || $check_order > 0) {
                return true;
            }
            return false;
        }

        public function display_popup()
        {
            $is_old = $this->check_availability();
            $popup_html = "";
            $popup_html .= "<div class='popup shirtee_popup' id='shirtee_popup'>";
            $popup_html .= "<div class='popup_container'>";
            $popup_html .= "<div class='shirtee_popup_close'></div>";
            $popup_html .= "<div class='popup_container_content'>";
            $popup_html .= "<p>".__("You are successfully registered with shirtee cloud advanced control panel.", "shirtee-products-1")."</p>";
            $popup_html .= "<p>".__("Please click on button access advanced control panel", "shirtee-products-1")."</p>";
            $popup_html .= $this->advanced_login_form();
            if ($is_old) {
                $popup_html .= "<p class='migrate'>".__("We are migrating your store details with shirtee cloud.Please stay connect we will update you shortly.", "shirtee-products-1")."</p>";
            }
            $popup_html .= "</div>";
            $popup_html .= "</div>";
            $popup_html .= "</div>";
            return $popup_html;
        }

        public function advanced_login_form()
        {
            $form_html    = '';
            $access_token = $this->shirtee_settings('access_token');
            $settings     = $this->shirtee_settings();
            $form_html   .= "<form action='https://shirtee.cloud/wooLogin' method='POST' target='_blank'>";
            $form_html   .= "<input type='hidden' value='{$access_token}' name='access_token' id='access_token' />";
            $form_html   .= "<input type='hidden' value='1' name='login' id='login' />";
            $form_html   .= "<input type='hidden' value='{$settings['email']}' name='email' id='email' />";
            $form_html   .= "<input type='hidden' value='{$settings['designer_id']}' name='designer_id' id='designer_id' />";
            $form_html   .= "<input type='submit' value='Open Dashboard' name='advanced_panel' id='advanced_panel' class='btn btn_advanced_panel' />";
            $form_html   .= "</form>";
            return $form_html;
        }

        public function zendesk_info()
        {
            if ($this->check_designer()) {
                $res_data = $this->execute_curl('', 'zendesk_info');
                if ( isset($res_data['status']) && ($res_data['status'] == 'success') ) {
                    return $res_data['msg'];
                }
            }
        }

        public function wallet()
        {
            if ($this->check_designer()) {
                $res_data = $this->execute_curl('', 'wallet_info');
                if ( isset($res_data['status']) && ($res_data['status'] == 'error') ) {
                    return $res_data['msg'];
                }
            }
        }
        public function iframCreateProduct()
        {
         
                $res_data = $this->execute_curl('', 'iframCreateProduct');
                if ( isset($res_data['status']) && ($res_data['status'] == 'success') ) {
                    return $res_data['msg'];
                }
         
        }

        public static function shirtee_settings($field = 'import_settings')
        {
            global $wpdb;
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
            $settings = $wpdb->get_row("SELECT settings_value FROM {$tbl_settings} WHERE settings_name = '{$field}'");
            if (empty($settings)) {
                return;
            }
            if (empty($settings->settings_value)) {
                $wpdb->delete(
                    $tbl_settings,
                    array(
                        'settings_name' => $field
                    )
                );
                return;
            }
            if ($field == 'import_settings') {
                $setting = unserialize($settings->settings_value);
            } else {
                $setting = $settings->settings_value;
            }
            return $setting;
        }

        public function shirtee_language_load_textdomain()
        {
            load_plugin_textdomain('shirtee-products-1', false,basename(SHIRTEE_ROOT_DIR).'/languages');
        }

        public function shirtee_plugin_redirect()
        {
            if (get_option('shirtee_redirect_to_help', false) == 0) {
                update_option('shirtee_redirect_to_help', 1, false);
                exit(wp_safe_redirect(admin_url("/admin.php?page=add-settings")));
            }
        }

        public function shirtee_admin_menu()
        {
            $settings     = $this->shirtee_settings();  
            add_menu_page(
                __('Dashboard', 'shirtee-products-1'),
                __('Dashboard', 'shirtee-products-1'),
                'manage_options',
                'dashboard',
                array($this, 'dashboard'),
                SHIRTEE_ROOT_PATH . '/assets/img/favicon_02.png',
                56
            );
             add_submenu_page(
                'dashboard',
                __('Products', 'shirtee-products-1'),
                __('Products', 'shirtee-products-1'),
                'manage_options',
                'shirtee-products',
                array($this, 'shirtee_simple_product_listing')
            );
            if( isset($settings['dropshipping']) && ($settings['dropshipping'] == "yes") ){
                 add_submenu_page(
                    'dashboard',
                    __('Add Products', 'shirtee-products-1'),
                    __('Add Products', 'shirtee-products-1'),
                    'manage_options',
                    'shirtee-create-products',
                    array($this, 'shirtee_create_products')
                );
            }
            add_submenu_page(
                'dashboard',
                __('Orders', 'shirtee-products-1'),
                __('Orders', 'shirtee-products-1'),
                'manage_options',
                'shirtee-orders',
                array($this, 'shirtee_order_listing')
            );
            add_submenu_page(
                'dashboard',
                __('Settings', 'shirtee-products-1'),
                __('Settings', 'shirtee-products-1'),
                'manage_options',
                'add-settings',
                array($this, 'shirtee_add_settings')
            );
            add_submenu_page(
                'dashboard',
                __('Help', 'shirtee-products-1'),
                __('Help', 'shirtee-products-1'),
                'manage_options',
                'help-guide',
                array($this, 'shirtee_help_guide')
            );
        }

        public function shirtee_enqueue_scripts()
        {
            $page = isset($_GET['page']) && $_GET['page'] != '' ? $_GET['page'] : '';
            if (empty($page)) {
                return;
            }
            if (in_array($page, $this->_shirtee_pages)) {
                wp_register_style('shirtee-font-css', SHIRTEE_ROOT_PATH . 'assets/css/font-awesome.min.css', array(), rand(), false);
                wp_register_style('shirtee-select2-css', SHIRTEE_ROOT_PATH . 'assets/css/select2.min.css', array(), rand(), false);
                wp_register_style('shirtee-notify-css', SHIRTEE_ROOT_PATH . 'assets/css/jquery.notify.css', array(), rand(), false);
                wp_register_style('shirtee-style-css', SHIRTEE_ROOT_PATH . 'assets/css/style.css', array(), rand(), false);
                
                wp_enqueue_style('shirtee-font-css');
                wp_enqueue_style('shirtee-select2-css');
                wp_enqueue_style('shirtee-notify-css');
                wp_enqueue_style('shirtee-style-css');

                wp_enqueue_script('jquery');

                wp_register_script('shirtee-select2-js', SHIRTEE_ROOT_PATH . 'assets/js/select2.min.js', array('jquery'), rand(), true);
                wp_register_script('shirtee-notify-js', SHIRTEE_ROOT_PATH . 'assets/js/jquery.notify.js', array('jquery'), rand(), true);
                wp_register_script('shirtee-simple_product-js', SHIRTEE_ROOT_PATH . 'assets/js/simple_product.js', array('jquery'), rand(), true);
                wp_register_script('shirtee-order-js', SHIRTEE_ROOT_PATH . 'assets/js/order_data.js', array('jquery'), rand(), true);

                wp_enqueue_script('shirtee-select2-js');
                wp_enqueue_script('shirtee-notify-js');
                wp_enqueue_script('shirtee-simple_product-js');
                wp_enqueue_script('shirtee-order-js');

                wp_localize_script(
                    'shirtee-simple_product-js',
                    'shirtee_vars',
                    array(
                        'PLUGIN_URL'            => SHIRTEE_ROOT_PATH,
                        'ADMIN_URL'             => admin_url('admin-ajax.php'),
                        'LOGIN_TO_SHIRTEE'      => 'login_to_shirtee',
                        'LOGIN_SHIRTEE_API'     => 'login_to_shirtee_api',
                        'EMAIL_RESEND'          => 'email_resend',
                        'CHANGE_REGISTRATION'   => 'change_registration',
                        'FETCH_DATA'            => 'fetch_data',
                        'INSERT_CRON'           => 'woo_product_schedule_process',
                        'PRODUCT_LIST'          => 'products_list',
                        'DATA_PAGINATION'       => 'shirtee_pagination',
                        'REMOVE_PRODUCT'        => 'woo_remove_shirtee_product'
                    )
                );
                wp_localize_script(
                    'shirtee-order-js',
                    'shirtee_order_vars',
                    array(
                        'ADMIN_URL'        => admin_url('admin-ajax.php'),
                        'ORDER_PAGINATION' => 'shirtee_pagination',
                        'ORDER_LIST'       => 'order_list'
                    )
                );
            }
        }

        public function shirtee_frontend_enqueue_scripts()
        {
            wp_register_style('shirtee-style-css', SHIRTEE_ROOT_PATH . 'assets/css/public/shirtee-front-end.css');
            wp_enqueue_style('shirtee-style-css');

            wp_enqueue_script('jquery');
            wp_register_script('shirtee-front-js', SHIRTEE_ROOT_PATH . 'assets/js/public/shirtee-front-end.js', array('jquery'), null, true);
            wp_enqueue_script('shirtee-front-js');
        }

        public function shirtee_header()
        {
            if (!defined('ABSPATH')) {
                die();
            }
            $curentPage   = isset($_GET['page']) && !empty($_GET['page']) ? $_GET['page'] : '';
            $settings     = $this->shirtee_settings();
            $access_token = $this->shirtee_settings('access_token');
            if (($settings === false || empty($settings) || empty($access_token)) && ($curentPage != 'add-settings' && $curentPage != 'help-guide')) {
                exit(wp_safe_redirect(admin_url('admin.php?page=add-settings')));
            }
            echo $this->wallet();

            echo $this->zendesk_info();?>
            <div class="wrap">
                <h2></h2>
            </div>
            <div class="clear"></div>
            <div class="wrap">
                <div class="loader_area">
                    <div class="loader"></div>
                    <div class="loader_text">Please Wait...</div>
                </div>
                <div class="shirtee-container">
                    <?php echo $this->shirtee_navigation();
        }

        public function shirtee_navigation()
        {   
            //get api data and update in settings table end
            $import_settings = $this->shirtee_settings('import_settings');
            $proUrl = "";
            $lang ="de";
            if( isset($import_settings['dropshipping']) && ($import_settings['dropshipping'] == 'yes') ){
                $proUrl = get_admin_url()."admin.php?page=shirtee-create-products";
            }  else {
                if( isset($import_settings['lang']) ){
                    $lang = $import_settings['lang'];
                }
                $proUrl = "https://www.shirtee.com/".$lang."/designer/?id=1140/";
            }
            
            if (isset($_GET['page']) && !empty($_GET['page'])) {
                $page = $_GET['page'];
                
                
            } ?>
            <header>
                <section class="dashboard-navigation">
                    <div class="container">
                        <ul>
                            <li <?php if($page == 'dashboard'){ echo 'class=active'; } ?>><a href="admin.php?page=dashboard"><?php _e('Dashboard', 'shirtee-products-1'); ?></a></li>
                            <li <?php if($page == 'shirtee-products'){ echo 'class=active'; } ?>><a href="admin.php?page=shirtee-products"><?php _e('Products', 'shirtee-products-1'); ?></a></li>
                            <li <?php if($page == 'shirtee-create-products'){ echo 'class=active'; } ?>><a href="<?php echo $proUrl;?>"><?php _e('Add Products', 'shirtee-products-1'); ?></a></li>
                            <li <?php if($page == 'shirtee-orders'){ echo 'class=active'; } ?>><a href="admin.php?page=shirtee-orders"><?php _e('Orders', 'shirtee-products-1'); ?></a></li>
                            <li <?php if($page == 'add-settings'){ echo 'class=active'; } ?>><a href="admin.php?page=add-settings"><?php _e('Settings', 'shirtee-products-1'); ?></a></li>
                            <li <?php if($page == 'help-guide'){ echo 'class=active'; } ?>><a href="admin.php?page=help-guide"><?php _e('Help', 'shirtee-products-1'); ?></a></li>
                            <?php if ($this->check_designer()) { ?>
                            <li ><?php echo $this->advanced_login_form(); ?></li>
                            <?php } ?>
                        </ul>
                    </div>
                </section>
            </header>
            <?php
        }

        public function shirtee_footer()
        {
            echo "</div>"; /* .shirtee-container */
            echo "</div>"; /* .wrap */
        }

        public function dashboard(){

            $this->shirtee_header();
            global $wpdb;
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
           
            $firstname    = "";//$settings['firstname'];
            $lastname     = "";//$settings['lastname'];            
            //get api data and update in settings table
            $woo_token = $this->shirtee_settings('woo_token');
            if( isset($_GET['method']) && $_GET['method'] == "storapi" && empty($woo_token)  ){
                $res_data = $this->execute_curl('', 'restapi_detail');              
                if( isset($res_data['status']) && ($res_data['status']=="success") ){                
                    $wooToken = $res_data['data']['apidata'];
                    $tbl_shirtee_import_settings = "{$wpdb->prefix}shirtee_import_settings";
                    
                    if (!empty($woo_token)) {
                        $wpdb->update(
                            $tbl_shirtee_import_settings,
                            array(
                                'settings_value' => $wooToken
                            ),
                            array(
                                'settings_name'  => 'woo_token'
                            )
                        );
                    } else {
                        $wpdb->insert(
                            $tbl_shirtee_import_settings,
                            array(
                                'settings_name'  => 'woo_token',
                                'settings_value' => $wooToken
                            )
                        );
                    }
                }
            }
            //get api data and update in settings table end
            $import_settings = $this->shirtee_settings('import_settings');
            $proUrl = "";
            $lang ="de";
            if( isset($import_settings['dropshipping']) && ($import_settings['dropshipping'] == 'yes') ){
                $proUrl = get_admin_url()."admin.php?page=shirtee-create-products";
            }  else {
                if( isset($import_settings['lang']) ){
                    $lang = $import_settings['lang'];
                }
                $proUrl = "https://www.shirtee.com/".$lang."/designer/?id=1140/";
            }
            
            ?>

            <section class="dashboard-welcome-section">
                <div class="container">
                        <div class="dashboard-welcome-wrapper">
                            <div class="dashboard-welcome-row">
                                <div class="dashboard-welcome-col dashboard-welcome-left">
                                    <h1 class="pagee-title"><?php _e("Welcome ", "shirtee-products-1"); echo $firstname." ".$lastname.'!'?></h1>
                                    <div class="dashboard-welcome-middle">
                                       <p> <?php _e("Thank you for using our App. Use the Shirtee.Cloud to create custom design products for your store and drop ship them all over the world with no costs and no risks. Please see our next steps on how to get started.", "shirtee-products-1"); ?>
                                        </p>
                                        <div class="button-row">
                                            <a class="btn primary-btn" href="<?php echo $proUrl;?>"><?php _e("Create your own products", "shirtee-products-1"); ?></a>
                                        </div>
                                    </div>
                                </div>
                                <div class="dashboard-welcome-col dashboard-next-step-col-right">
                                    <h1 class="pagee-title"><?php _e("Your next steps: ", "shirtee-products-1"); ?></h1>
                                   
                                    <div class="dashboard-welcome-middle dashboard-next-step-list">
                                        <p> <?php _e("Use our <a href='$proUrl' target='_blank'>Product Creator</a> to create your own unique products. Apply your designs to our print-on-demand products and together they will build your self created product collection for your shop.", "shirtee-products-1"); ?>
                                        </p>
                                        <p> <?php _e("Go to <a href='admin.php?page=shirtee-products'>Products</a> and import the products your created into your Woocommerce shop.", "shirtee-products-1"); ?>
                                        </p>
                                        <p> <?php _e("Deposit money to your <a href='https://dashboard.shirtee.cloud/wallet/auto-payment'>Go to Wallet ></a>. The wallet is used to settle the product and production costs. We’ll charge your Wallet for all incoming orders.", "shirtee-products-1"); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
                </div>
            </section>
            <section class="three-col-pow-section">
                    <div class="container">
                        <div class="three-col-row">
                            <div class="three-col">
                                <div class="three-col-inner">
                                    <h3 class="pagee-title"><?php _e("Products ", "shirtee-products-1"); ?></h3>
                                    <p><?php _e("Import newly created products and get an overview of all previously created and already imported products. ", "shirtee-products-1"); ?>
                                    </p>
                                    <div class="go-more-link">
                                        <a href="admin.php?page=shirtee-products"><?php _e("Go to Products >", "shirtee-products-1"); ?></a>
                                    </div>
                                </div>
                            </div>
                            <div class="three-col">
                                <div class="three-col-inner">
                                    <h3 class="pagee-title"><?php _e("Orders ", "shirtee-products-1"); ?></h3>
                                    <p><?php _e("The Shirtee App will automatically detect all print-on-demand orders from your WooCommerce shop and will send them to our production.", "shirtee-products-1"); ?>
                                    </p>
                                    <div class="go-more-link">
                                        <a href="admin.php?page=shirtee-orders"><?php _e("Go to Orders >", "shirtee-products-1"); ?></a>
                                    </div>
                                </div>
                            </div>
                            <div class="three-col">
                                <div class="three-col-inner">
                                    <h3 class="pagee-title"><?php _e("Wallet ", "shirtee-products-1"); ?></h3>
                                    <p><?php _e("Deposit money to your Wallet, check the current balance of your wallet and see all latest Wallet transactions.", "shirtee-products-1"); ?>
                                    </p>
                                    <div class="go-more-link">
                                        <a href="https://dashboard.shirtee.cloud/wallet/auto-payment"><?php _e("Go to Wallet >", "shirtee-products-1"); ?></a>
                                    </div>
                                </div>
                            </div>
                        </div> 
                    </div>
            </section>

       <?php $this->shirtee_footer(); 
    }
        public function shirtee_simple_product_listing()
        {
            $this->shirtee_header();
            $is_migrating = $this->shirtee_settings('is_migrated');
            $access_token = $this->shirtee_settings('access_token');
            $settings = $this->shirtee_settings();
            $dropuser = "no";
            if( isset($settings ['dropshipping']) && ($settings['dropshipping'] == "yes") )
            {
                 $dropuser = "yes"; 
            }
            global $wpdb;
            $tableName = "{$wpdb->prefix}shirtee_import_products";
            $products  = $wpdb->get_results("SELECT product_title FROM {$tableName} WHERE status = 1 GROUP BY product_title"); ?>
            <section class="shirtee-products-table-list product-table-section">
                <div class="container">
                    
                    <?php if (!$this->is_shirtee_required_plugin_activate()) { ?>
                        <div class="notice notice-error">
                            <p class="plugin-error"><?php _e("Woocommerce is not installed or activated in your site.Please install or activate woocommerce to use Shirtee Products Importer features.", "shirtee-products-1"); ?></p>
                        </div>
                    <?php } else {  if (!empty($access_token) && !empty($is_migrating) && $is_migrating == 'no') { ?>
                            <div class="migration">
                                <div class="migration_overlay"></div>
                                <div class="migration_text">
                                    <p><?php _e("We are migrating your store details with advanced control panel. Please stay connect we will update you shortly.", "shirtee-products-1"); ?></p>
                                </div>
                            </div>
                            <input type="hidden" value=1 name="is_migration" id="is_migration" />
                        <?php } ?>
                        <div class="update-list-wrap">
    
                            <div class="update-button-row">
                                <h2 class="pagee-title"><?php _e("Shirtee Products", "shirtee-products-1") ?></h2>
                                <div class="update">
                                    <a class="update_list export-import-tag import-selected" href="javascript:void(0)" id="fetch-data" <?php if($dropuser == "yes") { ?> style="visibility:hidden" <?php } ?>><?php _e("Get products from Shirtee", "shirtee-products-1"); ?></a>

                                    <a href="javascript:void(0);" class="update_list add-import-tag import-selected disabled_link" id="all-importproduct" <?php if($dropuser == "yes") { ?> style="visibility:hidden" <?php } ?> ><?php _e("Import/Update selected products", "shirtee-products-1"); ?></a>

                                    <a href="javascript:void(0);" class="remove-products update_list add-remove-tag import-selected disabled_link" id="all-remove"><?php _e("Remove", "shirtee-products-1"); ?></a>
                                </div>
                            </div>
                            <div class="search-main">
                                <div class="result-wrap">
                                    <select name="total-data" id="total-data">
                                        <option value="10">10</option>
                                        <option value="20">20</option>
                                        <option value="30">30</option>
                                        <option value="40">40</option>
                                        <option value="50">50</option>
                                    </select>
                                    <?php _e('result', 'shirtee-products-1'); ?>
                                </div>
                            </div>
                            <div class="serach serach-product">
                                <div class="market-place-right">
                                    <div class="form-item">
                                    <div class="search_loader">
                                        <div class="loader"></div>
                                    </div>

                                    <div id="frm_search">
                                        <?php if (!empty($products)) { ?>
                                            <div class="product-select">
                                                <div class="main_filter">
                                                    <div class="filter_data">
                                                        <label><?php _e('Product', 'shirtee-products-1'); ?></label>
                                                        <select name="product_type" id="product_type">
                                                            <option value="all">All</option>
                                                            <?php for ($i = 0; $i < count($products); $i++) {
                                                                echo "<option value='" . $products[$i]->product_title . "'>" . $products[$i]->product_title . "</option>";
                                                            } ?>
                                                        </select>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php } ?>
                                        <!-- <div class="product-select warehouse-select">
                                            <div class="main_filter warehouse">
                                                <div class="filter_data"> 
                                                    <label>Warehouse</label>
                                                    <select name="is_warehouse" id="is_warehouse" class="product-select-box-selectpicker" data-show-subtext="true" data-live-search="true" tabindex="-98">
                                                        <option value="">All</option>
                                                        <option value="1">Yes</option>
                                                        <option value="0">No</option>
                                                    </select>
                                                </div>
                                            </div>
                                        </div> -->
                                        <div class="search_item">
                                            <input type="text" name="search-pro" id="search-pro" class="searchbox" placeholder="Search Products">
                                            <img id="img_search" src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/search-icon.svg'; ?>">
                                        </div>
                                    </div>
                                </div>
                                </div>
                      
                                <div class="tab-list">
                                    <div class="import-item">
                                        <ul id="import-filter">
                                            <li>
                                                <a href="javascript:void(0);" data-value='all' class="active">
                                                    <?php _e("All", "shirtee-products-1");
                                                    echo shirtee_products_count(); ?>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="javascript:void(0);" data-value='0'>
                                                    <?php _e("Imported", "shirtee-products-1");
                                                    echo shirtee_products_count(0); ?>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="javascript:void(0);" data-value='1'>
                                                    <?php _e("Not Imported", "shirtee-products-1");
                                                    echo shirtee_products_count(1); ?>
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
        
                        <div id="all-result">
                            <?php echo $this->products_list_table(); ?>
                        </div>
                    <?php } ?>
                </div>
            </section>
            <input type="hidden" name="cuser" id="cuser" value="<?php echo get_current_user_id() != 0 ? get_current_user_id() : 1; ?>" />
            <?php
            $this->shirtee_footer();
        }
        public function shirtee_create_products()
        {
            $this->shirtee_header();
            $is_migrating = $this->shirtee_settings('is_migrated');
            $access_token = $this->shirtee_settings('access_token');
            $settings = $this->shirtee_settings();
            $dropuser = "no";
            if( isset($settings ['dropshipping']) && ($settings['dropshipping'] == "yes") )
            {
                 $dropuser = "yes"; 
            }
            $woo_token = $this->shirtee_settings('woo_token'); //woo_token
            if ( empty($woo_token) ) { //woo_token
                exit(wp_safe_redirect(admin_url('admin.php?page=add-settings'))); //woo_token
            } //woo_token            
            global $wpdb;
            $tableName = "{$wpdb->prefix}shirtee_import_products";
            $products  = $wpdb->get_results("SELECT product_title FROM {$tableName} WHERE status = 1 GROUP BY product_title"); ?>
            <section>
                <div class="container">
                    <h1 class="pagee-title"><?php _e("Shirtee Create Products", "shirtee-products-1") ?></h1>
                    <?php if (!$this->is_shirtee_required_plugin_activate()) { ?>
                        <div class="notice notice-error">
                            <p class="plugin-error"><?php _e("Woocommerce is not installed or activated in your site.Please install or activate woocommerce to use Shirtee Products Importer features.", "shirtee-products-1"); ?></p>
                        </div>
                    <?php } else { if (!empty($access_token) && !empty($is_migrating) && $is_migrating == 'no') { ?>
                            <div class="migration">
                                <div class="migration_overlay"></div>
                                <div class="migration_text">
                                    <p><?php _e("We are migrating your store details with advanced control panel. Please stay connect we will update you shortly.", "shirtee-products-1"); ?></p>
                                </div>
                            </div>
                            <input type="hidden" value=1 name="is_migration" id="is_migration" />
                        <?php } ?>
         
                        <div id="all-result">
                            <?php echo $this->iframCreateProduct(); ?>
                        </div>
                    <?php } ?>
                </div>
            </section>
           
            <?php
            $this->shirtee_footer();
        }
        public function shirtee_order_listing()
        {
            $this->shirtee_header();
            $is_migrating = $this->shirtee_settings('is_migrated');
            $access_token = $this->shirtee_settings('access_token'); ?>
            <section>
                <div class="container">
                    <h1 class="pagee-title"><?php _e("Orders", "shirtee-products-1"); ?></h1>
                    <?php if (!$this->is_shirtee_required_plugin_activate()) { ?>
                        <div class="notice notice-error">
                            <p class="plugin-error"><?php _e("Woocommerce is not installed or activated in your site.Please install or activate woocommerce to use Shirtee Products Importer features.", "shirtee-products-1", "shirtee-products-1"); ?></p>
                        </div>
                    <?php } else { if (!empty($access_token) && !empty($is_migrating) && $is_migrating == 'no') { ?>
                            <div class="migration">
                                <div class="migration_overlay"></div>
                                <div class="migration_text"><p><?php _e("We are migrating your store details with advanced control panel. Please stay connect we will update you shortly.", "shirtee-products-1"); ?></p></div>
                            </div>
                            <input type="hidden" value=1 name="is_migration" id="is_migration" />
                        <?php } ?>
                        <div class="update-list-wrap">
                
                            <div class="search search-order">
                                <div class="form-item">
                                    <div class="search_loader">
                                        <div class="loader"></div>
                                    </div>
                                    <div id="frm_search">
                                        <div class="search_item">
                                            <input type="text" name="search-order" id="search-order" class="searchbox" placeholder="Search Order">
                                            <img id="img_search" src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/search_icon.svg'; ?>">
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="search-main">
                                <div class="result-wrap">
                                    <select name="total-data" id="total-order">
                                        <option value="10">10</option>
                                        <option value="20">20</option>
                                        <option value="30">30</option>
                                        <option value="40">40</option>
                                        <option value="50">50</option>
                                    </select>
                                    <?php _e('result', 'shirtee-products-1'); ?>
                                </div>
                            </div>
                        </div>
                        <div id="all-result">
                            <?php echo $this->order_listing(); ?>
                        </div>
                    <?php } ?>
                </div>
            </section>
            <?php $this->shirtee_footer();
        }

        public function shirtee_register_settings()
        {
           // $this->shirtee_header();
            global $wpdb;
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
            $settings     = $this->shirtee_settings();
            $is_login     = $this->shirtee_settings('is_logged_in');
            $access_token = $this->shirtee_settings('access_token');
            $is_migrating = $this->shirtee_settings('is_migrated');
            $email        = $username = $password = $catID = "";
            $varLimit     = 200;
            $implang      = 'de';
             ?>
              <section class="login-regiser-page-screen-thanks-message">
                    <div class="container">
                        <div class="wrap shirtee-settings">
                            <div class="two-col">
                                <div class="">
                                    <p class="thanks-message-text"><?php _e("Thanks for choosing the Shirtee.Cloud. To get started, please first confirm your e-mail address, We have sent to activation code.", "shirtee-products-1"); ?>
                                    </p>
                                    <div class= "resend-reset button-row">
                                        <form name="shirtee-resend-form" id="shirtee-resend-form" method="post">
                                            <input type="hidden" id="resend_email" value="<?php echo site_url(); ?>" name="resend_email" />
                                            <a href="javascript:void(0);" name="email-resend" id="email-resend" class="button btn primary-btn"><?php _e("Resend", "shirtee-products-1"); ?></a>
                                            <span id="shirtee-resend-error" class="error" style="display: none;"><?php _e("Limit exceeded for email sending", "shirtee-products-1"); ?></span>
                                            <input type="hidden" id="change_registration" value="change-registration" name="change_registration" />
                                             <a href="javascript:void(0);" id= "change-registration" name="change-registration" class="button btn secondary-btn"><?php _e("Change registration", "shirtee-products-1"); ?></a>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
            <?php  
            //$this->shirtee_footer();
        }

        public function shirtee_add_settings()
        {
            $this->shirtee_header();
            global $wpdb;
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
            $settings     = $this->shirtee_settings();
            $is_login     = $this->shirtee_settings('is_logged_in');
            $access_token = $this->shirtee_settings('access_token');
            $is_migrating = $this->shirtee_settings('is_migrated');
            $email        = $username = $password = $catID = "";
            $account_info = unserialize($this->shirtee_settings('account_info'));
            $varLimit     = 200;
            $implang      = 'de';

            $countryArray  =  include_once(SHIRTEE_ROOT_DIR.'/includes/classes/countryArray.php');

            $shirtee_register ="";
            $shirtee_register = $this->shirtee_settings('shirtee_register');
            
            if( !empty($shirtee_register) && ($shirtee_register == "deactive") ){
                    echo $this->shirtee_register_settings();
            } else {

            if (!$is_login && (!isset($settings['email']) || empty($settings['email']))) {
             ?>
                <section class="login-screen-new">
                    <div class="container">
                        <div class="wrap shirtee-settings">
                            <h1 class="pagee-title"><?php _e("Settings", "shirtee-products-1"); ?></h1>
                            <div class="form-middle align-center">
                                <div class="start-and-confirm-form-middle">
                                    <h2 class="pagee-title"><?php _e("Welcome to Shirtee", "shirtee-products-1"); ?></h2>
                                    <p><?php _e("To get started please type in your <br>e-mail address and password.", "shirtee-products-1"); ?></p>
                                    <form name="shirtee-login-form" id="shirtee-login-form" method="post">
                                        <div class="input-box">
                                            <div class="field-row">
                                                <div class="input-label"><?php _e("E-Mail", "shirtee-products-1"); ?> 
                                                <span>*</span></div>
                                                <div class="input-group">
                                                    <i class="icon-img">
                                                        <img src="<?php echo SHIRTEE_ROOT_PATH;?>assets/img/envelope.svg" alt="">
                                                    </i>
                                                    <input required="" id="shirtee_uname" autocomplete="off" name="shirtee_uname" class="input-text" placeholder="E-mail address" type="email" />
                                                </div>
                                                <span id="shirtee-username-error" class="error"><?php _e("Please enter valid Email ID", "shirtee-products-1"); ?></span>
                                            </div>
                                        </div>
                                        <div class="input-box">
                                            <div class="field-row">
                                                <div class="input-label"><?php _e("Password", "shirtee-products-1"); ?> <span>*</span></div>
                                                <div class="input-group">
                                                    <i class="icon-img">
                                                        <img src="<?php echo SHIRTEE_ROOT_PATH;?>assets/img/lock.svg" alt="">
                                                    </i>
                                                    <input required="" id="shirtee_pass" autocomplete="off" name="shirtee_pass" class="input-text" placeholder="Password" type="password" />
                                                </div>
                                                <span id="shirtee-pass-error" class="error"><?php _e("Please enter password", "shirtee-products-1"); ?></span>
                                            </div>
                                        </div>
                                        <input type="hidden" id="type" value="login" name="type" />
                                        <div class="input-box submit-box">
                                            <div class="field-row">
                                                <a href="javascript:void(0);" name="import-login" id="import-login" class="button btn-confirm btn-get-started"><?php _e("Get started", "shirtee-products-1"); ?></a>
                                            </div>
                                        </div>
                                        <!-- <a class="fogot-password-text" href='javascript:void(0);' name='fogot-password' id='fogot-password'>Forgot Password?</a> -->
                                        <!-- <span class="info required-fields-text"><i style="color: red; font-style: normal;">*</i> <?php _e("are the required fields.", "shirtee-products-1"); ?></span> -->
                                        <!-- <div class="register-button">
                                            <?php //echo sprintf("Don't have an account ? %s", "<a href='javascript:void(0);' name='register' id='register'>Click to Register</a>"); ?>
                                        </div> -->
                                    </form>
                                </div>
                            </div>
                            <input type="hidden" id="auth" value="<?php echo wp_create_nonce('shirtee-auth'); ?>" name="auth" />
                        </div>
                    </div>
                </section>
            <?php } else {
                
                $woo_token = $this->shirtee_settings('woo_token');
                //if (  !empty($settings['type'])   &&  ($settings['type'] =="register") && empty($woo_token) ) {                    
                if ( empty($woo_token) && !empty($settings['catID']) && (is_array($settings['catID']) && count($settings['catID'])==1) && !empty($settings['password']) ) {                        
                    ?>
                        <script type="text/javascript">
                             jQuery( window ).on( "load", function() {     
                                jQuery( "#shirtee-login" ).trigger( "click" );
                             });
                        </script>
                    <?php 
                }
                
                if (!$is_login && isset($settings['email']) && !empty($settings['email'])) {
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            "settings_name"   => "is_logged_in",
                            "settings_value"  => 1,
                        ),
                        array(
                            "%s,%d"
                        )
                    );
                }
                $placeholder = __("Enter Password", "shirtee-products-1");
                if (!empty($settings)) {
                    $username = isset($settings['username']) && !empty($settings['username']) ? $settings['username'] : '';
                    $password = isset($settings['password']) && !empty($settings['password']) ? $settings['password'] : '';
                    $catID    = isset($settings['catID'])    && !empty($settings['catID'])    ? $settings['catID']    : '';
                    if( is_array($catID) )
                    {
                         if( count($catID) == 1 )
                         {
                             $catID = $catID[0]; 
                         } 
                        
                    } else {
                        $catID = $catID;
                    }

                    $email    = isset($settings['email'])    && !empty($settings['email'])    ? $settings['email']    : '';
                    $varLimit = isset($settings['varLimit']) && !empty($settings['varLimit']) ? $settings['varLimit'] : 200;
                    $implang  = isset($settings['lang'])     && !empty($settings['lang'])     ? $settings['lang']     : 'de';
                    $product_status = isset($settings['product_status'])    && !empty($settings['product_status'])    ? $settings['product_status']    : '0';
                     $product_swatches = isset($settings['product_swatches'])    && !empty($settings['product_swatches'])    ? $settings['product_swatches']    : '0';
                    $product_title = isset($settings['product_title']) && !empty($settings['product_title'])    ? $settings['product_title'] : '0';
                    $product_description  = isset($settings['product_description']) && !empty($settings['product_description']) ? $settings['product_description'] : '0';
                    $product_price = isset($settings['product_price'])    && !empty($settings['product_price']) ? $settings['product_price'] : '0';
                    $product_image = isset($settings['product_image'])    && !empty($settings['product_image']) ? $settings['product_image'] : '0';
                    
                   
                  


                    /* Account Details*/

                    if( empty($account_info) ){
                        $account_info = $this->get_current_user_profile_data();                        
                        global $wpdb;
                        $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                        $checkaccount_info = $wpdb->get_results("SELECT 'settings_name' FROM {$tbl_settings} WHERE `settings_name` = 'account_info'");
                        if (empty($checkaccount_info)) {
                            $wpdb->insert(
                                $tbl_settings,
                                array(
                                "settings_name"  => "account_info",
                                "settings_value" => serialize($account_info)
                            )
                            );
                        }  
                    }  

                    
                    
                    $first_name = isset($account_info['firstname'])    && !empty($account_info['firstname'])    ? $account_info['firstname']    : '';
                    $last_name = isset($account_info['lastname'])    && !empty($account_info['lastname'])    ? $account_info['lastname']    : '';
                    $company_name = isset($account_info['companyname'])    && !empty($account_info['companyname'])    ? $account_info['companyname']    : '';
                    $address = isset($account_info['address'])    && !empty($account_info['address'])    ? $account_info['address']    : '';                    
                    $zip_code = isset($account_info['zip'])    && !empty($account_info['zip'])    ? $account_info['zip']    : '';
                    $city = isset($account_info['city'])    && !empty($account_info['city'])    ? $account_info['city']    : '';
                    $country = isset($account_info['country'])    && !empty($account_info['country'])    ? $account_info['country']    : '';
                    $phone = isset($account_info['phone'])    && !empty($account_info['phone'])    ? $account_info['phone']    : '';
                    $vat_number = isset($account_info['vatnumber'])    && !empty($account_info['vatnumber'])    ? $account_info['vatnumber']    : '';

                    if ($password != '') {
                        $pswd = str_repeat("*", strlen($password));
                        $placeholder = $pswd;
                    }
                } ?>
                <section>
                    <div class="container">
                        <div class="wrap shirtee-settings">
                            <h1 class="pagee-title"><?php _e("Settings", "shirtee-products-1"); ?></h1>

                            <?php if (!empty($access_token) && !empty($is_migrating) && $is_migrating == 'no') { ?>
                                <div class="migration">
                                    <div class="migration_overlay"></div>
                                    <div class="migration_text">
                                        <p><?php _e("We are migrating your store details with advanced control panel. Please stay connect we will update you shortly.", "shirtee-products-1"); ?></p>
                                    </div>
                                </div>
                                <input type="hidden" value=1 name="is_migration" id="is_migration" />
                            <?php } ?>
                            <div class="form-middle align-center">
                                <div class="start-and-confirm-form-middle">
                                    <h2>Confirm your details</h2>
                                    <p>Please check your account details and confirm</p>
                                <form name="import-section" method="post" action="">
                                    <div id="fields">
                                        <div class="input-box">
                                            <?php 
                                        if (empty($username) || empty($password)) { ?>
                                            <div class="field-row">
                                                <div class="field-col">
                                                    <div class="input-box shirtee-credentials">
                                                        <div class="input-label"><?php _e("Shirtee API Username", "shirtee-products-1"); ?> <span>*</span></div>
                                                        <input required="" id="username" name="username" value="<?php echo $username; ?>" class="input-text" placeholder="Username" type="email" />
                                                        <span id="shirtee-user-error" class="error"><?php _e("Please enter valid Email ID", "shirtee-products-1"); ?></span>
                                                    </div>
                                                </div>
                                                <div class="field-col">
                                                    <div class="input-box shirtee-credentials">
                                                        <div class="input-label"><?php _e("Shirtee API Password", "shirtee-products-1"); ?> <span>*</span></div>
                                                        <input required="" id="password" name="password" class="input-text" placeholder="<?php echo $placeholder; ?>" type="password" />
                                                        <?php if ($password == '') { ?>
                                                            <span class="error show error-api"><?php _e("Please contact your administrator for password", "shirtee-products-1"); ?></span>
                                                        <?php } ?>
                                                        <span id="shirtee-pswd-error" class="error"><?php _e("Please enter valid Password", "shirtee-products-1"); ?></span>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php } ?>
                                         <?php 
                                        //cho $this->check_WC_auth_url_access(); ?>
                                        <div class="field-row ex-space">
                                            <div class="field-col">
                                                
                                         <?php  if( ( is_array($catID) ) && (count($catID) != 1) && ($catID > 1) )
                                                     {  ?>
                                                     <div class="input-label"><?php _e("Select your Shirtee Shop ID", "shirtee-products-1"); ?> <span>*</span></div>
                                                         <select id="catID" name="catID" class="select-text">
                                                         <option value=""><?php _e("Please Select Shirtee Shop ID", "shirtee-products-1"); ?> </option>
                                                         <?php foreach($catID as $cat){ ?>
                                                         <option value="<?php echo $cat; ?>"><?php echo $cat; ?> </option>
                                                            <?php } ?>  
                                                         </select>
                                             <span id="shirtee-cat-error" class="error show"><?php _e("Please Select Shirtee Shop ID", "shirtee-products-1"); ?></span>
                                                         <?php                                                     
                                                }  else { ?>
                                                <div class="input-label"><?php _e("Shirtee Shop ID", "shirtee-products-1"); ?> <span>*</span></div>
                                        <input required="" id="catID" name="catID" value="<?php echo $catID; ?>" class="input-text" placeholder="Shirtee Shop ID" type="text" readonly/>
                                           <?php if ($catID = '') { ?>
                                            <span id="shirtee-cat-error" class="error show"><?php _e("Please enter Shirtee Shop ID", "shirtee-products-1"); ?></span>
                                        <?php } ?>              
                                                <?php } ?>
                                            </div>
                                        <div class="field-col">
                                        <div class="input-label"><?php _e("Select your Shop Language", "shirtee-products-1"); ?></div>
                                        <select id="implang" name="implang" class="select-text">
                                            <option value="de" <?php echo $implang == 'de' ? "selected='selected'" : ''; ?>> <?php _e("German", "shirtee-products-1"); ?> </option>
                                            <option value="en" <?php echo $implang == 'en' ? "selected='selected'" : ''; ?>> <?php _e("English", "shirtee-products-1"); ?> </option>
                                            <option value="da" <?php echo $implang == 'da' ? "selected='selected'" : ''; ?>> <?php _e("Danish", "shirtee-products-1"); ?> </option>
                                            <option value="es" <?php echo $implang == 'es' ? "selected='selected'" : ''; ?>> <?php _e("Spanish", "shirtee-products-1"); ?> </option>
                                            <option value="fi" <?php echo $implang == 'fi' ? "selected='selected'" : ''; ?>> <?php _e("Finnish", "shirtee-products-1"); ?> </option>
                                            <option value="fr" <?php echo $implang == 'fr' ? "selected='selected'" : ''; ?>> <?php _e("French", "shirtee-products-1"); ?> </option>
                                            <option value="it" <?php echo $implang == 'it' ? "selected='selected'" : ''; ?>> <?php _e("Italian", "shirtee-products-1"); ?> </option>
                                            <option value="nl" <?php echo $implang == 'nl' ? "selected='selected'" : ''; ?>> <?php _e("Dutch", "shirtee-products-1"); ?> </option>
                                            <option value="nb" <?php echo $implang == 'nb' ? "selected='selected'" : ''; ?>> <?php _e("Norwegian bokmål", "shirtee-products-1"); ?> </option>
                                            <option value="pl" <?php echo $implang == 'pl' ? "selected='selected'" : ''; ?>> <?php _e("Polish", "shirtee-products-1"); ?> </option>
                                            <option value="pt" <?php echo $implang == 'pt' ? "selected='selected'" : ''; ?>> <?php _e("Portuguese", "shirtee-products-1"); ?> </option>
                                            <option value="sv" <?php echo $implang == 'sv' ? "selected='selected'" : ''; ?>> <?php _e("Swedish", "shirtee-products-1"); ?> </option>
                                        </select>
                                        <!-- <span><?php _e("Language of the Shirtee product content.", "shirtee-products-1"); ?></span> -->
                                        </div>
                                    </div>
                                    </div>
                                    <div class="input-box">
                                        <div class="field-row">
                                            <div class="field-col">
                                                <div class="input-label"><?php _e("First Name", "shirtee-products-1"); ?> <span>*</span></div>
                                                <div class="input-group">
                                                    <input required="" id="first_name" autocomplete="none" name="first_name" class="input-text" placeholder="First Name" type="text" value="<?php echo $first_name;?>" />
                                                </div>
                                                <span id="shirtee-fname-error" class="error"><?php _e("Please enter your first name", "shirtee-products-1"); ?></span>
                                            </div>
                                            <div class="field-col">
                                                <div class="input-label"><?php _e("Last Name", "shirtee-products-1"); ?> <span>*</span></div>
                                                <div class="input-group">
                                                    <input required="" id="last_name" autocomplete="none" name="last_name" class="input-text" placeholder="Last Name" type="text" value="<?php echo $last_name;?>" />
                                                </div>
                                                <span id="shirtee-lname-error" class="error"><?php _e("Please enter your Last name", "shirtee-products-1"); ?></span>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="input-box">
                                        <div class="field-row">
                                            <div class="input-label"><?php _e("Company (optional)", "shirtee-products-1"); ?></div>
                                            <input id="company_name" name="company_name" value="<?php echo $company_name; ?>" class="input-text" placeholder="Company" type="text" /> 
                                        </div>                                       
                                    </div>
                                    <div class="input-box">
                                        <div class="field-row">
                                            <div class="input-label"><?php _e("Address", "shirtee-products-1"); ?><span>*</span></div>
                                            <div class="input-group">
                                                <input id="address" name="address" value="<?php echo $address; ?>" class="input-text" placeholder="Address" type="text" />                                        
                                            </div> 
                                            <span id="shirtee-address-error" class="error"><?php _e("Please enter your Address", "shirtee-products-1"); ?></span>
                                        </div>
                                    </div>
                                    <div class="input-box">
                                        <div class="field-row">
                                            <div class="field-col">
                                                <div class="field-row">
                                                    <div class="field-col">
                                                        <div class="input-label"><?php _e("ZIP Code", "shirtee-products-1"); ?><span>*</span></div>
                                                        <div class="input-group">
                                                            <input id="zip_code" name="zip_code" value="<?php echo $zip_code; ?>" class="input-text" placeholder="Zip" type="text" />                                        
                                                        </div>
                                                        <span id="shirtee-zipcode-error" class="error"><?php _e("Please enter your ZIP code", "shirtee-products-1"); ?></span>
                                                    </div>
                                                    <div class="field-col">
                                                        <div class="input-label"><?php _e("City", "shirtee-products-1"); ?><span>*</span></div>
                                                        <div class="input-group">
                                                            <input id="city" name="city" value="<?php echo $city; ?>" class="input-text" placeholder="City" type="text" />                                        
                                                        </div>
                                                        <span id="shirtee-city-error" class="error"><?php _e("Please enter your City", "shirtee-products-1"); ?></span>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="field-col">
                                                <div class="input-label"><?php _e("Country", "shirtee-products-1"); ?></div>
                                                <select id="country" name="country" class="select-text">
                                                    <?php 
                                                    foreach ($countryArray as $key => $value) { ?>
                                                        <option value="<?php echo $key; ?>" <?php echo $country == $key ? "selected='selected'" : ''; ?>> <?php echo $value; ?> </option>
                                                   <?php  }
                                                    ?> 
                                                </select>
                                                <!-- <span id="shirtee-country-error" class="error"><?php _e("Please select your Country", "shirtee-products-1"); ?></span> -->
                                            </div>
                                        </div>
                                    </div>
                                    <div class="input-box">
                                        <div class="field-row">
                                            <div class="field-col">
                                                <div class="input-label"><?php _e("Phone", "shirtee-products-1"); ?><span>*</span></div>
                                                <div class="input-group">
                                                    <input id="phone" name="phone" value="<?php echo $phone; ?>" class="input-text" placeholder="Phone" type="text" />                                        
                                                    <span><?php _e("Add telephone number with country code", "shirtee-products-1"); ?></span>
                                                </div>
                                                <span id="shirtee-phone-error" class="error"><?php _e("Please enter your Phone", "shirtee-products-1"); ?></span>
                                            </div>
                                            <div class="field-col">
                                                <div class="input-label"><?php _e("VAT Number", "shirtee-products-1"); ?></div>
                                                <div class="input-group">
                                                    <input id="vat_number" name="vat_number" value="<?php echo $vat_number; ?>" class="input-text" placeholder="VAT Number" type="text" />                                        
                                                </div>
                                                <!-- <span id="shirtee-vatnumber-error" class="error"><?php _e("Please enter your VAT Number", "shirtee-products-1"); ?></span> -->
                                            </div>
                                        </div>
                                        <div class="field-row">
                                            
                                            <div class="field-col">
                                                <div class="input-label"><?php _e("Variation Limits", "shirtee-products-1"); ?></div>
                                                <input id="varlimit" name="varlimit" value="<?php echo $varLimit; ?>" class="input-text" placeholder="Variation Limits" type="text" />
                                                <!-- <span><?php _e("Fix for issue where too many variations causes the front end to not pre-load all variations and rely on AJAX.", "shirtee-products-1"); ?></span> -->
                                            </div>
                                              <div class="field-col">
                                                <div class="input-label"><?php _e("Product Status", "shirtee-products-1"); ?><span>*</span></div>
                                                <select id="product_status" name="product_status" class="select-text">
                                                  <option value="">Select Product Status</option>   
                                                  <option value="1" <?php echo $product_status == '1' ? "selected='selected'" : ''; ?>> <?php _e("Publish Products", "shirtee-products-1"); ?> </option>
                                                  <option value="0" <?php echo $product_status == '0' ? "selected='selected'" : ''; ?>> <?php _e("Draft Products", "shirtee-products-1"); ?> </option>
                                                 
                                                 
                                                    
                                                </select>
                                                <span id="shirtee-product_status-error" class="error"><?php _e("Please select your Product Status", "shirtee-products-1"); ?></span> 
                                            </div>
                                        </div>
                                        
                                    </div>
                                    <div class="input-box">
                                        <div class="field-row">
                                            <div class="field-col">
                                                <div class="input-label">Select Swatches<span></span></div>
                                                <select id="product_swatches" name="product_swatches" class="select-text">
                                                <option value="1" <?php echo $product_swatches == '1' ? "selected='selected'" : ''; ?>> <?php _e("Customize Swatches", "shirtee-products-1"); ?>  </option>
                                                 <option value="0" <?php echo $product_swatches == '0' ? "selected='selected'" : ''; ?>><?php _e("Default Swatches", "shirtee-products-1"); ?>  </option>
                                                 
                                                 </select>
                                             </div>
                                        </div>
                                    </div>
                                    <div class="input-box">
                                            <div class="field-row">
                                                <div class="field-col">
                                                    <div class="input-labels setting-lable">Product Update Exclude Fields<span></span></div>
                                                    <div class="setting-form-element">
                                                        <div class="nice-checkbox nice-checkbox-inline">
                                                            <div class="setting-form-field">
                                                                <input class="checkbox_setting" type="checkbox" name="product_title_checkbox" id="product_title_checkbox" value="1"  <?php echo $product_title == '1' ? 'checked' : ''; ?>>
                                                                <label class="label-text setting-lable" for="product_title_checkbox">Product Title</label>
                                                            </div>
                                                             <div class="setting-form-field">
                                                                <input class="checkbox_setting" type="checkbox" name="product_description_checkbox" id="product_description_checkbox" value="1" <?php echo $product_description == '1' ? 'checked' : ''; ?>>
                                                                <label class="label-text setting-lable" for="product_description_checkbox">Product Description</label>
                                                            </div>
                                                            <div class="setting-form-field">
                                                                <input class="checkbox_setting" type="checkbox" name="product_price_checkbox" id="product_price_checkbox" value="1" <?php echo $product_price == '1' ? 'checked' : ''; ?>>
                                                                <label class="label-text setting-lable" for="product_price_checkbox">Price</label>
                                                            </div>
                                                            <div class="setting-form-field">
                                                                <input class="checkbox_setting" type="checkbox" name="product_image_checkbox" id="product_image_checkbox" value="1" <?php echo $product_image == '1' ? 'checked' : ''; ?>>
                                                                <label class="label-text setting-lable" for="product_image_checkbox">Product Images</label>
                                                            </div>
                                                           
                                                        </div>
                                                     </div>
                                                 </div>
                                            </div>
                                        </div>
                                
                                </div>
                                    <div class="input-box hidden">
                                        <div class="input-label"><?php _e("Email", "shirtee-products-1"); ?> <span>*</span></div>
                                        <input id="email" name="email" value="<?php echo $email; ?>" class="input-text" placeholder="Email" type="hidden" />
                                    </div>  
                                    <div class="input-box hidden">
                                        <input id="old_password" name="old_password" value="<?php echo $password; ?>" class="input-text" type="hidden" />
                                    </div>
                                    <input type="hidden" id="api-auth" value="<?php echo wp_create_nonce('shirtee-api-auth'); ?>" name="api-auth" />
                                    <div class="input-box submit-box">
                                        <div class="field-row">
                                            <a href="javascript:void(0);" id="shirtee-login" class="button btn-confirm">
                                                <?php _e("Confirm", "shirtee-products-1"); ?>
                                            </a>
                                            <?php
                                            $woo_token = $this->shirtee_settings('woo_token');                                      
                                            if( empty($woo_token) ){
                                             echo $this->check_WC_auth_url_access(); 
                                            }?>
                                        </div>
                                    </div>
                                    <!-- <span class="info"><span class="red">*</span> <?php _e("are the required fields.", "shirtee-products-1"); ?></span> -->
                                </form>
                            </div>
                            </div>
                        </div>
                    </div>
                </section>
            <?php } }
            $this->shirtee_footer();
        }
        public function check_WC_auth_url_access(){               
            $access_token = $this->shirtee_settings('access_token');
            
            
            $store_url = home_url( '/' );
            $endpoint = '/wc-auth/v1/authorize';
            $params = [
                'app_name' => 'Shirtee',
                'scope' => 'read_write',
                'user_id' => 1,               
                'return_url' => $store_url.'wp-admin/admin.php?page=dashboard&method=storapi',
                'callback_url' => 'https://apibridge.shirtee.cloud/woo_api/stage_check/crons/class-import-product-restapi.php?method=storeapi&site_url='.rtrim(site_url(), "/")
            ];           
                
            $query_string = http_build_query( $params );
            $url =  $store_url . $endpoint . '?' . $query_string;
            echo '<a href="' . esc_url($url) . '" id="auth-url-acces" class="button auth-url-acces' . ( ! empty( $issues ) ? 'disabled' : '' ) . '" target="_blank" style="visibility:hidden">' . esc_html__('Connect', 'shirtee-cloud') . '</a>';
        }
        public function shirtee_help_guide()
        {
            $this->shirtee_header(); ?>
            <section>
                <div class="container">
                    <h1 class="pagee-title"><?php _e("Help Guide", "shirtee-import-products"); ?></h1>
                    <div class="naccs">
                        <div class="grid">
                            <div class="gc gc--1-of-3">
                                <div class="hmenu">
                                    <div class="active">
                                        <span class="light"></span>
                                        <span><?php _e("Products", "shirtee-products-1"); ?></span>
                                    </div>
                                    <div>
                                        <span class="light"></span>
                                        <span><?php _e("Orders", "shirtee-products-1"); ?></span>
                                    </div>
                                    <div>
                                        <span class="light"></span>
                                        <span><?php _e("Settings", "shirtee-products-1"); ?></span>
                                    </div>
                                    <div>
                                        <span class="light"></span>
                                        <span><?php _e("System Status", "shirtee-products-1"); ?></span>
                                    </div>
                                </div>
                            </div>
                            <div class="gc gc--2-of-3">
                                <ul class="nacc">
                                    <li class="active">
                                        <p><img src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> As a dropshipper, you can create custom products for your store and drop ship them worldwide with no costs or risks. Follow these steps to get started:
                                            
                                        </p>
                                        <ol class="ol-sub-listing">
                                            <li>Log in to your Shirtee dashboard.
                                            </li>
                                              <li>Click on "Add Products" in the left menu.</li>
                                              <li>Create your product and it will automatically sync with WooCommerce.</li>
                                        </ol>
                                        <p>&nbsp;</p>
                                        <p><img src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> If you're a shirtee.com user:
                                        
                                        </p>
                                        <ul class="ul-sub-listing">
                                            <li>Click the "Get products from Shirtee" button in your Shirtee App. The app will fetch your product(s) and display them in a grid view.</li>
                                            <li>To import Shirtee product(s) in your WooCommerce store, select the product(s) and click on the "Import/Update" button.</li>
                                            <li>When the import process is completetd, you'll find the selected product(s) in your store.</li>
                                            <li>You can always update product(s) later. Just select the product(s) and click on "Import/Update".</li>
                                        </ul>
                                        <p>&nbsp;</p>
                                        <p><img src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> In woo default product create with draft also Shirtee Dashboard > Settings here "Product Status" dropdown for product publish or draft product create</p>
                                        <p>&nbsp;</p>
                                        <p><img src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> In woo default product create variation swatches udpated default wordpress also customize with shirtee Shirtee Dashboard > Settings here "Select Swatches" here can manage when product create  </p>
                                        <p>&nbsp;</p>
                                        <p><img src="<?php echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> For product create we have added shirtee sku so don't change variation sku its depends on shirtee orders </p>
                                    </li>
                                    <li>
                                        <ul class="ul-sub-listing">
                                            <li>The Shirtee App automatically syncs any orders on WooCommerce and sends it to your Shirtee store.</li>
                                            <li>When the status of an order changes to "Processing/Completed" in WooCommerce it will be synced with Shirtee.</li>
                                        </ul>

                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> </p>
                                        <p>&nbsp;</p>
                                        <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> </p> -->
                                    </li>
                                    <li>
                                        <ol class="ol-sub-listing">
                                            <li>Navigate to wp-admin > Settings > Permalinks > Common Settings. Here, select "Post name" and scroll down to "Save Changes".</li>
                                            <li>Navigate to Dashboard > Settings. Here, add your login information from https://dashboard.shirtee.cloud/login to connect your shop.</li>
                                        </ol>
                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> Navigate to wp-admin > Settings > Permalinks > Common Settings. Here, select "Post name" and scroll down to "Save Changes".</p>
                                        <p>&nbsp;</p>
                                        <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> Navigate to Dashboard > Settings. Here, add your login information from https://dashboard.shirtee.cloud/login to connect your shop.</p> -->
                                        
                                        <ul class="ul-sub-listing" style="margin-left:3em;">
                                            <li>If you don't have any login information, enter a new email and password to connect your WooCommerce shop.</li>              
                                        </ul>
                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> If you don't have any login information, enter a new email and password to connect your WooCommerce shop. </p> -->
                                        <ul class="ul-sub-listing">
                                            <li>If you encounter any IP block issues, add the Shirtee IP to your white list: 188.166.172.107</li>
                                            <li>In shop for product create using REST API so when configure plugin that time we genereate with rest api key with name "Shirtee - API Read/Write" its require for product create please don't delete this key</li>
                                            <li>In shop when shirtee product create that we call shirtee api so request send to api with get response data form shirtee so third party request and response enable in website</li>
                                            <li>If you have further questions, feel free to contact our <a href="mailto:support@shirtee.com">Support team.</a></li>              
                                        </ul>
                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> If you encounter any IP block issues, add the Shirtee IP to your white list: 188.166.172.107 </p>
                                        <p>&nbsp;</p> -->
                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> In shop for product create using REST API so when configure plugin that time we genereate with rest api key with name "Shirtee - API Read/Write" its require for product create please don't delete this key</p>
                                        <p>&nbsp;</p> -->
                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>"> In shop when shirtee product create that we call shirtee api so request send to api with get response data form shirtee so third party request and response enable in website </p>
                                        <p>&nbsp;</p> -->
                                        <!-- <p><img src="<?php //echo SHIRTEE_ROOT_PATH . '/assets/img/bullet.gif'; ?>">
                                            If you have further questions, feel free to contact our <a href="mailto:support@shirtee.com">Support team.</a>
                                        </p> -->
                                    </li>
                                    <li>
                                        <?php $system_status = $this->get_environment_info();
                                        // System Requirements
                                        $recommendations = array(
                                            'wp_memory_limit'     => '128M',
                                            'max_execution_time'  => '360',
                                            'max_input_time'      => '600',
                                            'upload_max_filesize' => '4M',
                                            'post_max_size'       => '4M',
                                        ); ?>
                                        <table class="form-table">
                                            <tbody>
                                                <tr>
                                                    <td><?php _e('WordPress memory limit', 'shirtee-products-1') . ":"; ?>
                                                    </td>
                                                    <td>
                                                        <?php if ($system_status['wp_memory_limit'] < $this->size_to_num($recommendations['wp_memory_limit'])) {
                                                            /* Translators: %1$s: Memory limit, %2$s: Docs link, %3$s: Recommended Memory. */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('%1$s - We recommend setting memory to at least %3$s. See: %2$s', 'shirtee-products-1'),
                                                                    esc_html(size_format($system_status['wp_memory_limit'])),
                                                                    '<a href="https://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP" rel="noopener" target="_blank">' . __('Increasing memory allocated to PHP', 'shirtee-products-1') . '</a>',
                                                                    $recommendations['wp_memory_limit']
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes">' . esc_html(size_format($system_status['wp_memory_limit'])) . '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('PHP time limit', 'shirtee-products-1') . ":"; ?>
                                                    </td>
                                                    <td>
                                                        <?php if ($system_status['php_max_execution_time'] < $recommendations['max_execution_time']) {
                                                            /* Translators: %1$s: Execution Time, %2$s: Docs link, %3$s: Recommended Memory. */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('%1$s - We recommend setting maximum Execution time to at least %3$s. See: %2$s', 'shirtee-products-1'),
                                                                    esc_html($system_status['php_max_execution_time']),
                                                                    '<a href="https://www.wpbeginner.com/wp-tutorials/how-to-increase-the-maximum-file-upload-size-in-wordpress/" rel="noopener" target="_blank">' . __('Increase the Maximum Execution Time', 'shirtee-products-1') . '</a>',
                                                                    $recommendations['max_execution_time']
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes">' . esc_html($system_status['php_max_execution_time']) . '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('PHP input time', 'shirtee-products-1') . ":"; ?>
                                                    </td>
                                                    <td>
                                                        <?php if ($system_status['php_max_input_time'] < $recommendations['max_input_time']) {
                                                            /* Translators: %1$s: Input Time, %2$s: Docs link, %3$s: Recommended Memory. */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('%1$s - We recommend setting maximum input time to at least %3$s. See: %2$s', 'shirtee-products-1'),
                                                                    esc_html($system_status['php_max_input_time']),
                                                                    '<a href="http://www.wpbeginner.com/wp-tutorials/how-to-increase-the-maximum-file-upload-size-in-wordpress/" rel="noopener" target="_blank">' . __('Increase the Maximum Input Time', 'shirtee-products-1') . '</a>',
                                                                    $recommendations['max_input_time']
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes">' . esc_html($system_status['php_max_input_time']) . '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('PHP Max Upload Size', 'shirtee-products-1') . ":"; ?>
                                                    </td>
                                                    <td>
                                                        <?php if ($system_status['max_upload_size'] < $this->size_to_num($recommendations['upload_max_filesize'])) {
                                                            /* Translators: %1$s: Upload Size, %2$s: Docs link, %3$s: Recommended Memory. */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('%1$s - We recommend setting maxium upload filesize to at least %3$s. See: %2$s', 'shirtee-products-1'),
                                                                    esc_html(size_format($system_status['max_upload_size'])),
                                                                    '<a href="http://www.wpbeginner.com/wp-tutorials/how-to-increase-the-maximum-file-upload-size-in-wordpress/" rel="noopener" target="_blank">' . __('Increase the Maximum File Upload Size', 'shirtee-products-1') . '</a>',
                                                                    $recommendations['upload_max_filesize']
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes">' . esc_html(size_format($system_status['max_upload_size'])) . '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('PHP post max size', 'shirtee-products-1') . ":"; ?>
                                                    </td>
                                                    <td>
                                                        <?php if ($system_status['php_post_max_size'] < $this->size_to_num($recommendations['post_max_size'])) {
                                                            /* Translators: %1$s: Upload Size, %2$s: Docs link, %3$s: Recommended Memory. */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('%1$s - We recommend setting maxium post size to at least %3$s. See: %2$s', 'shirtee-products-1'),
                                                                    esc_html(size_format($system_status['php_post_max_size'])),
                                                                    '<a href="http://www.wpbeginner.com/wp-tutorials/how-to-increase-the-maximum-file-upload-size-in-wordpress/" rel="noopener" target="_blank">' . __('Increase the Maximum Post Size', 'shirtee-products-1') . '</a>',
                                                                    $recommendations['post_max_size']
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes">' . esc_html(size_format($system_status['php_post_max_size'])) . '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('Curl Version', 'shirtee-products-1') . ":"; ?></td>
                                                    <td>
                                                        <?php if (empty($system_status['curl_version'])) {
                                                            /* Translators: %1$s: CRUL Link */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('We requires CURL to work our plugin. See: %1$s', 'shirtee-products-1'),
                                                                    '<a href="https://www.luminanetworks.com/docs-lsc-610/Topics/SDN_Controller_Software_Installation_Guide/Appendix/Installing_cURL_for_Ubuntu_1.html" rel="noopener" target="_blank">' . __('Installing CURL', 'shirtee-products-1') . '</a>'
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes"><span class="dashicons dashicons-yes"></span>' . esc_html($system_status['curl_version']) . '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('Woocommerce', 'shirtee-products-1') . ":"; ?></td>
                                                    <td>
                                                        <?php if (false === $system_status['is_woo_activate']) {
                                                            /* Translators: %1$s: CRUL Link */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('We requires Woocommerce to work Shirtee plugin. %1$s from here', 'shirtee-products-1'),
                                                                    '<a href="' . admin_url('plugin-install.php?s=woocommerce&tab=search&type=term') . '" rel="noopener" target="_blank">' . __('Install plugin', 'shirtee-products-1') . '</a>'
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes">';
                                                                echo '<span class="dashicons dashicons-yes"></span>';
                                                                if (!empty($system_status['woo_plugin_data']['version_latest']) && version_compare($system_status['woo_plugin_data']['version_latest'], $system_status['woo_plugin_data']['version'], '>')) {
                                                                    /* translators: %s: plugin latest version */
                                                                    echo ' &ndash; <strong class="shirtee-red">' . sprintf(__('%s is available', 'shirtee-products-1'), $plugin['version_latest']) . '</strong>';
                                                                }
                                                            echo '</mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('Shirtee API Email', 'shirtee-products-1') . ":"; ?></td>
                                                    <td>
                                                        <?php if (empty($system_status['shirtee_credentials']['email'])) {
                                                            /* Translators: %1$s: Settings Page Link */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('We requires API Email Address to work our plugin. Go to %1$s to set your API settings', 'shirtee-products-1'),
                                                                    '<a href="' . admin_url('admin.php?page=add-settings') . '" rel="noopener">' . __('Settings Page', 'shirtee-products-1') . '</a>'
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes"><span class="dashicons dashicons-yes"></span></mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('Shirtee API Username', 'shirtee-products-1') . ":"; ?></td>
                                                    <td>
                                                        <?php if (empty($system_status['shirtee_credentials']['username'])) {
                                                            /* Translators: %1$s: Settings Page Link */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('We requires API Username to work our plugin. Go to %1$s to set your API settings', 'shirtee-products-1'),
                                                                    '<a href="' . admin_url('admin.php?page=add-settings') . '" rel="noopener">' . __('Settings Page', 'shirtee-products-1') . '</a>'
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes"><span class="dashicons dashicons-yes"></span></mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('Shirtee API Password', 'shirtee-products-1') . ":"; ?></td>
                                                    <td>
                                                        <?php if (empty($system_status['shirtee_credentials']['password'])) {
                                                            /* Translators: %1$s: Settings Page Link */
                                                            echo '<mark class="error"><span class="dashicons dashicons-warning"></span> ' .
                                                                sprintf(
                                                                    __('We requires API Password to work our plugin. Go to %1$s to set your API settings', 'shirtee-products-1'),
                                                                    '<a href="' . admin_url('admin.php?page=add-settings') . '" rel="noopener">' . __('Settings Page', 'shirtee-products-1') . '</a>'
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes"><span class="dashicons dashicons-yes"></span></mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td><?php _e('Shirtee Access Token', 'shirtee-products-1') . ":"; ?></td>
                                                    <td>
                                                        <?php if (empty($system_status['shirtee_credentials']['access_token'])) {
                                                            /* Translators: %1$s: Settings Page Link */
                                                            echo '<mark class="error"><span class="dashicons dashicons-no"></span> ' .
                                                                sprintf(
                                                                    __('We requires SHIRTEE Access Token to work our plugin. Go to %1$s to set your API settings', 'shirtee-products-1'),
                                                                    '<a href="' . admin_url('admin.php?page=add-settings') . '" rel="noopener">' . __('Settings Page', 'shirtee-products-1') . '</a>'
                                                                )
                                                                . '</mark>';
                                                        } else {
                                                            echo '<mark class="yes"><span class="dashicons dashicons-yes"></span></mark>';
                                                        } ?>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <?php $this->shirtee_footer();
        }

        public function get_environment_info()
        {
            // WP memory limit.
            $wp_memory_limit = $this->size_to_num(WP_MEMORY_LIMIT);
            if (function_exists('memory_get_usage')) {
                $wp_memory_limit = max($wp_memory_limit, $this->size_to_num(@ini_get('memory_limit')));
            }

            // Figure out cURL version, if installed.
            $curl_version = '';
            if (function_exists('curl_version')) {
                $curl_version = curl_version();
                $curl_version = $curl_version['version'] . ', ' . $curl_version['ssl_version'];
            }

            $settings     = $this->shirtee_settings();
            $access_token = '';
            $access_token = $this->shirtee_settings('access_token');
            $settings['access_token'] = $access_token;

            $plugin_file = WP_PLUGIN_DIR . '/woocommerce/woocommerce.php';
            $plugin_Data = get_plugin_data($plugin_file);

            return array(
                'wp_version'                => get_bloginfo('version'),
                'wp_multisite'              => is_multisite(),
                'wp_memory_limit'           => $wp_memory_limit,
                'wp_debug_mode'             => (defined('WP_DEBUG') && WP_DEBUG),
                'server_info'               => isset($_SERVER['SERVER_SOFTWARE']) ? sanitize_text_field(wp_unslash($_SERVER['SERVER_SOFTWARE'])) : '', // Content escaped
                'is_woo_activate'           => SHIRTEE_IMPORTER::is_shirtee_required_plugin_activate(),
                'woo_plugin_data'           => $plugin_Data,
                'php_version'               => phpversion(),
                'php_post_max_size'         => $this->size_to_num(ini_get('post_max_size')),
                'php_upload_max_filesize'   => $this->size_to_num(ini_get('upload_max_filesize')),
                'php_max_execution_time'    => ini_get('max_execution_time'),
                'php_max_input_vars'        => ini_get('max_input_vars'),
                'php_max_input_time'        => ini_get('max_input_time'),
                'curl_version'              => $curl_version,
                'max_upload_size'           => wp_max_upload_size(),
                'shirtee_credentials'       => $settings,
            );
        }

        public function size_to_num($size)
        {
            $l    = substr($size, -1);
            $ret  = substr($size, 0, -1);
            $byte = 1024;

            switch (strtoupper($l)) {
                case 'P':
                    $ret *= $byte;
                    // No break.
                case 'T':
                    $ret *= $byte;
                    // No break.
                case 'G':
                    $ret *= $byte;
                    // No break.
                case 'M':
                    $ret *= $byte;
                    // No break.
                case 'K':
                    $ret *= $byte;
                    // No break.
            }
            return $ret;
        }

        public function shirtee_product_delete($postid)
        {
            if (!$this->is_shirtee_plugin_activate()) {
                return;
            }
            global $post_type, $wpdb;
            if ($post_type != 'product') {
                return;
            }
            $mage_id = $wpdb->get_row("SELECT `product_mage_id` FROM {$wpdb->prefix}shirtee_import_products WHERE `product_woo_id` = {$postid}");
            if (!empty($mage_id)) {
                $data['mage_id'] = $mage_id->product_mage_id;
                $wpdb->update(
                    "{$wpdb->prefix}shirtee_import_products",
                    array(
                        "product_woo_id" => 0
                    ),
                    array(
                        "product_woo_id" => $postid
                    )
                );
                $this->execute_curl($data, "removed_from_woo");
            }
        }

        public function complete_registration_process($res_datas){

            if (!$this->is_shirtee_plugin_activate()) {
                return;
            }
            if ($res_datas['status'] == 'success') {
                global $wpdb;
                $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                $login = $wpdb->get_results("SELECT 'settings_name' FROM {$tbl_settings} WHERE `settings_name` = 'is_logged_in'");
                if (!empty($login)) {
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            "settings_value" => 1
                        ),
                        array(
                            "settings_name"  => "is_logged_in"
                        )
                    );
                } else {
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            "settings_name"  => "is_logged_in",
                            "settings_value" => 1
                        )
                    );
                }
                
                $setting = $this->shirtee_settings();
                $settings = array();
                if (!empty($setting)) {
                    if (isset($setting['email']) && !empty($setting['email']) && $setting['email'] == $res_datas['data']['email']) {
                        $settings['email'] = $setting['email'];
                    } elseif (!empty($res_datas['data']['email'])) {
                        $settings['email'] = $res_datas['data']['email'];
                    }
                    if (isset($setting['username']) && !empty($setting['username'])) {
                        $settings['username'] = $setting['username'];
                    } elseif (!empty($res_datas['data']['username'])) {
                        $settings['username'] = $res_datas['data']['username'];
                    }
                    if (isset($setting['password']) && !empty($setting['password'])) {
                        $settings['password'] = $setting['password'];
                    } elseif (!empty($res_datas['data']['password'])) {
                        $settings['password'] = $res_datas['data']['password'];
                    }
                    if (isset($setting['dropshipping']) && !empty($setting['dropshipping'])) {
                        $settings['dropshipping'] = $setting['dropshipping'];
                    } elseif (!empty($res_datas['data']['dropshipping'])) {
                        $settings['dropshipping'] = $res_datas['data']['dropshipping'];
                    }
                    
                    if (isset($setting['designer_id']) && !empty($setting['designer_id'])) {
                        $settings['designer_id'] = $setting['designer_id'];
                    } elseif (!empty($designer_id['data']['did'])) {
                        $settings['designer_id'] = $res_datas['data']['did'];
                    }
                    
                    if (isset($setting['catID']) && !empty($setting['catID'])) {
                        $settings['catID'] = $setting['catID'];
                    } elseif (!empty($res_datas['data']['cid'])) {
                        $settings['catID'] = $res_datas['data']['cid'];
                    }
                    if (isset($setting['varLimit']) && !empty($setting['varLimit'])) {
                        $settings['varLimit'] = $setting['varLimit'];
                    } else {
                        $settings['varLimit'] = 200;
                    }
                    if (isset($setting['lang']) && !empty($setting['lang'])) {
                        $settings['lang'] = $setting['lang'];
                    } else {
                        $settings['lang'] = 'de';
                    }
                    if( $data['type'] == "register"){ //check register 
                        $settings['type'] = 'register';
                    }
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            "settings_value" => serialize($settings)
                        ),
                        array(
                            "settings_name"  => "import_settings"
                        )
                    );
                } else {
                    if (isset($res_datas['data']['email']) && !empty($res_datas['data']['email'])) {
                        $settings['email'] = $res_datas['data']['email'];
                    }
                    if (isset($res_datas['data']['username']) &&  !empty($res_datas['data']['username'])) {
                        $settings['username'] = $res_datas['data']['username'];
                    }
                    if (isset($res_datas['data']['password']) && !empty($res_datas['data']['password'])) {
                        $settings['password'] = $res_datas['data']['password'];
                    }
                    if (isset($res_datas['data']['dropshipping']) && !empty($res_datas['data']['dropshipping'])) {
                        $settings['dropshipping'] = $res_datas['data']['dropshipping'];
                    }
                    if (isset($res_datas['data']['cid']) && !empty($res_datas['data']['cid'])) {                       
                        $settings['catID'] = $res_datas['data']['cid'];
                     }
                    if (isset($res_datas['data']['did']) && !empty($res_datas['data']['did'])) {
                        $settings['designer_id'] = $res_datas['data']['did'];
                    }
                    if (isset($res_datas['data']['firstname']) && !empty($res_datas['data']['firstname'])){
                        $settings['firstname'] = $res_datas['data']['firstname'];
                    }
                    if (isset($res_datas['data']['lastname']) && !empty($res_datas['data']['lastname'])){
                        $settings['lastname'] = $res_datas['data']['lastname'];
                    }
                    if( isset($data['type']) && $data['type'] == "register"){
                        $settings['type'] = 'register';
                    }
                    $settings['varLimit'] = 200;
                    $settings['lang'] = 'de';
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            "settings_name"  => "import_settings",
                            "settings_value" => serialize($settings)
                        )
                    );
                }
               
                if (empty($res_datas['data']['password'])) {
                   
                    return wp_send_json(array("status" => "success", "msg" => __("{$res_datas['msg']}.Please contact administrator for password.Please wait you will be redirect to SHIRTEE API login page.", "shirtee-products-1")));
                } else {

                   
                   // return wp_send_json(array("status" => "success", "msg" => __("{$res_datas['msg']}.Please wait you will be redirect to setting page, settings saving and connect with API123.", "shirtee-products-1")));
                }
            } else {
                return wp_send_json($res_datas);
            }
        }

        public function login_to_shirtee()
        {
            if (!$this->is_shirtee_plugin_activate()) {
                return;
            }
            if (!check_ajax_referer('shirtee-auth', 'auth')) {
                wp_send_json(array("status"  => "error", "msg" => "Access Denied."));
            }
            $data['type']     = !empty($_REQUEST['type'])     ? $_REQUEST['type']     : 'login';
            $data['username'] = !empty($_REQUEST['username']) ? $_REQUEST['username'] : '';
            $data['password'] = !empty($_REQUEST['password']) ? $_REQUEST['password'] : '';
            
            if ($data['type'] == 'register') {
                $data['firstname'] = !empty($_REQUEST['first_name']) ? $_REQUEST['first_name'] : '';
                $data['lastname']  = !empty($_REQUEST['last_name'])  ? $_REQUEST['last_name']  : '';
                $data['email']     = !empty($_REQUEST['email'])      ? $_REQUEST['email']      : '';
                if (empty($data['username'])) {
                    $data['username'] = $data['email'];
                }
            }

            if ($data['type'] == 'login') {

                $res_data = $this->execute_curl($data, "register_designer_new");
                
            } else{

                $res_data = $this->execute_curl($data, "login_register_designer");
            } 
            
                    
            
            if($res_data['msg'] == 'Logged in successfully...'){

                if ($res_data['status'] == 'success') {
                global $wpdb;
                $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                $login = $wpdb->get_results("SELECT 'settings_name' FROM {$tbl_settings} WHERE `settings_name` = 'is_logged_in'");
                if (!empty($login)) {
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            "settings_value" => 1
                        ),
                        array(
                            "settings_name"  => "is_logged_in"
                        )
                    );
                } else {
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            "settings_name"  => "is_logged_in",
                            "settings_value" => 1
                        )
                    );
                }
                    
                //profile data get from cloud or profile and insert/update    
                $profileData = array();    
                if( isset($res_data['data']['profile']) && !empty($res_data['data']['profile']) ){ 
                   
                    $profileData['firstname'] = $res_data['data']['profile']['firstname'];
                    $profileData['lastname'] = $res_data['data']['profile']['lastname'];
                    $profileData['companyname'] = $res_data['data']['profile']['company'];
                    $profileData['address'] = $res_data['data']['profile']['firstadd']." ".$res_data['data']['profile']['secondadd'];
                    $profileData['zip'] = $res_data['data']['profile']['zip'];
                    $profileData['city'] = $res_data['data']['profile']['city'];
                    $profileData['country'] = $res_data['data']['profile']['country'];
                    $profileData['phone'] = $res_data['data']['profile']['telephone'];
                    $profileData['vatnumber'] = $res_data['data']['profile']['vat'];
                    global $wpdb;
                    $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                    $account_info = $wpdb->get_results("SELECT 'settings_name' FROM {$tbl_settings} WHERE `settings_name` = 'account_info'");
                    if (!empty($account_info)) {
                        $wpdb->update(
                            $tbl_settings,
                            array(
                            "settings_value" => serialize($profileData)
                        ),
                            array(
                            "settings_name"  => 'account_info'
                        )
                        );
                    } else {
                        $wpdb->insert(
                            $tbl_settings,
                            array(
                            "settings_name"  => "account_info",
                            "settings_value" => serialize($profileData)
                        )
                        );
                    }
                }
                //profile data get from cloud or profile and insert/update 

                $setting = $this->shirtee_settings();
                $settings = array();
                if (!empty($setting)) {
                    if (isset($setting['email']) && !empty($setting['email']) && $setting['email'] == $res_data['data']['email']) {
                        $settings['email'] = $setting['email'];
                    } elseif (!empty($res_data['data']['email'])) {
                        $settings['email'] = $res_data['data']['email'];
                    }
                    if (isset($setting['username']) && !empty($setting['username'])) {
                        $settings['username'] = $setting['username'];
                    } elseif (!empty($res_data['data']['username'])) {
                        $settings['username'] = $res_data['data']['username'];
                    }
                    if (isset($setting['password']) && !empty($setting['password'])) {
                        $settings['password'] = $setting['password'];
                    } elseif (!empty($res_data['data']['password'])) {
                        $settings['password'] = $res_data['data']['password'];
                    }
                    if (isset($setting['dropshipping']) && !empty($setting['dropshipping'])) {
                        $settings['dropshipping'] = $setting['dropshipping'];
                    } elseif (!empty($res_data['data']['dropshipping'])) {
                        $settings['dropshipping'] = $res_data['data']['dropshipping'];
                    }
                    
                    if (isset($setting['designer_id']) && !empty($setting['designer_id'])) {
                        $settings['designer_id'] = $setting['designer_id'];
                    } elseif (!empty($designer_id['data']['did'])) {
                        $settings['designer_id'] = $res_data['data']['did'];
                    }
                    
                    $cid = $res_data['data']['cid'];
                    if( $res_data['data']['dropshipping'] == "no" )
                    {
                            $cid = implode(',', $cid); 
                    }
                    
                    if (isset($setting['catID']) && !empty($setting['catID'])) {
                        $settings['catID'] = $setting['catID'];
                    } elseif (!empty($res_data['data']['cid'])) {
                        $settings['catID'] = $cid;
                    }
                    
                    if (isset($setting['varLimit']) && !empty($setting['varLimit'])) {
                        $settings['varLimit'] = $setting['varLimit'];
                    } else {
                        $settings['varLimit'] = 200;
                    }
                    if (isset($setting['lang']) && !empty($setting['lang'])) {
                        $settings['lang'] = $setting['lang'];
                    } else {
                        $settings['lang'] = 'de';
                    }
                    if( $data['type'] == "register"){ //check register 
                        $settings['type'] = 'register';
                    }
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            "settings_value" => serialize($settings)
                        ),
                        array(
                            "settings_name"  => "import_settings"
                        )
                    );
                } else {
                    if (!empty($res_data['data']['email'])) {
                        $settings['email'] = $res_data['data']['email'];
                    }
                    if (!empty($res_data['data']['username'])) {
                        $settings['username'] = $res_data['data']['username'];
                    }
                    if (!empty($res_data['data']['password'])) {
                        $settings['password'] = $res_data['data']['password'];
                    }
                    if (!empty($res_data['data']['dropshipping'])) {
                        $settings['dropshipping'] = $res_data['data']['dropshipping'];
                    }
                    if (!empty($res_data['data']['cid'])) {                        
                       $settings['catID']=  $res_data['data']['cid'];
                    }
                    if (!empty($res_data['data']['did'])) {
                        $settings['designer_id'] = $res_data['data']['did'];
                    }
                    
                    if( $data['type'] == "register"){
                        $settings['type'] = 'register';
                    }
                    $settings['varLimit'] = 200;
                    $settings['lang'] = 'de';
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            "settings_name"  => "import_settings",
                            "settings_value" => serialize($settings)
                        )
                    );
                }
                    if (empty($res_data['data']['password'])) {
                       
                        return wp_send_json(array("status" => "success", "msg" => __("{$res_data['msg']}.Please contact administrator for password.Please wait you will be redirect to SHIRTEE API login page.", "shirtee-products-1")));
                    } else {

                        return wp_send_json(array("status" => "success", "msg" => __("{$res_data['msg']}.Please wait you will be redirect to setting page, settings saving and connect with API.", "shirtee-products-1")));
                    }

                } else {

                    return wp_send_json($res_datas);
                }
            } else {

                if($res_data['status'] == 'success'){

                    /*if($res_data['data'] == 'Register'){
                        
                        $res_data = $this->after_registration();
                        exit();
                    }*/
                    global $wpdb;
                    $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                    $shirtee_register = "";
                    $shirtee_register= $this->shirtee_settings('shirtee_register');
                    if ( empty($shirtee_register) ) {
                        $wpdb->insert(
                            $tbl_settings,
                            array(
                                "settings_name"   => "shirtee_register",
                                "settings_value"  => "deactive",
                            )
                        );
                    }
                    return wp_send_json($res_data);
                } else {
                    return wp_send_json($res_data);
                }
            }
           
        }
        public function get_current_user_profile_data(){ //get current user profile data 
            if( is_user_logged_in() ){
                $user_id = get_current_user_id();
                
                $billing_first_name =  get_user_meta( $user_id, 'first_name', true );
                $billing_last_name  = get_user_meta( $user_id, 'last_name', true );
                $billing_company    = get_user_meta( $user_id, 'billing_company', true );
                $billing_address_1  = get_user_meta( $user_id, 'billing_address_1', true );
                $billing_address_2  = get_user_meta( $user_id, 'billing_address_2', true );
                $billing_city       = get_user_meta( $user_id, 'billing_city', true );                        
                $billing_postcode   = get_user_meta( $user_id, 'billing_postcode', true );
                $billing_country    = get_user_meta( $user_id, 'billing_country', true );

                $profileData = array();
                if( !empty($billing_first_name) ){
                    $profileData['firstname'] = $billing_first_name;
                }
                if( !empty($billing_last_name) ){
                    $profileData['lastname'] = $billing_last_name;
                }
                if( !empty($billing_company) ){
                    $profileData['companyname'] = $billing_company;
                }
                if( !empty($billing_address_1) ){
                    $profileData['address'] = $billing_address_1." ".$billing_address_2;
                }
                if( !empty($billing_postcode) ){
                    $profileData['zip'] = $billing_postcode;
                }
                if( !empty($billing_city) ){
                    $profileData['city'] = $billing_city;
                }
                if( !empty($billing_country) ){
                    $profileData['country'] = $billing_country;
                }
                return $profileData;
            }

        }

        public function login_to_shirtee_api()
        {
            if (!$this->is_shirtee_plugin_activate()) {
                return;
            }
            if (!check_ajax_referer("shirtee-api-auth", 'apiauth')) {
                return wp_send_json(array("status" => "error", "msg" => "Access Denied."));
            }
            global $wpdb;
            global $wp_rewrite;
    
            $wp_rewrite->set_permalink_structure( $wp_rewrite->root . '/%postname%/' );
            $username     = $password = $catID = $varLimit = $email = '';
            $lang         = 'de';
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
            $setting      = $this->shirtee_settings();
            $access_token = $this->shirtee_settings('access_token');
            $account_info_detail = $this->shirtee_settings('account_info');

            $email    = !empty(trim($_REQUEST['email']))    ? trim($_REQUEST['email'])    : '';
            $username = !empty(trim($_REQUEST['username'])) ? trim($_REQUEST['username']) : '';
            $password = !empty(trim($_REQUEST['password'])) ? trim($_REQUEST['password']) : '';
            $catID    = !empty(trim($_REQUEST['catID']))    ? trim($_REQUEST['catID'])    : '';
            $lang     = !empty(trim($_REQUEST['lang']))     ? trim($_REQUEST['lang'])     : 'de';
            $varlimit = !empty(trim($_REQUEST['varlimit'])) ? trim($_REQUEST['varlimit']) : 200;

            /* Account Details*/

            $firstname   = !empty(trim($_REQUEST['first_name']))   ? trim($_REQUEST['first_name'])   : '';
            $lastname    = !empty(trim($_REQUEST['last_name']))    ? trim($_REQUEST['last_name'])    : '';
            $companyname = !empty(trim($_REQUEST['company_name'])) ? trim($_REQUEST['company_name']) : '';
            $address     = !empty(trim($_REQUEST['address']))      ? trim($_REQUEST['address'])      : '';
            $zip         = !empty(trim($_REQUEST['zip_code']))     ? trim($_REQUEST['zip_code'])     : '';
            $city        = !empty(trim($_REQUEST['city']))         ? trim($_REQUEST['city'])         : '';
            $country     = !empty(trim($_REQUEST['country']))      ? trim($_REQUEST['country'])      : '';
            $phone       = !empty(trim($_REQUEST['phone']))        ? trim($_REQUEST['phone'])        : '';
            $vatnumber   = !empty(trim($_REQUEST['vat_number']))   ? trim($_REQUEST['vat_number'])   : '';
            $product_status   = !empty(trim($_REQUEST['product_status']))   ? trim($_REQUEST['product_status'])   : '0';
           $product_swatches    = !empty(trim($_REQUEST['product_swatches']))   ? trim($_REQUEST['product_swatches'])   : '0';
            $product_title    = !empty(trim($_REQUEST['product_title_checkbox']))   ? trim($_REQUEST['product_title_checkbox'])   : '0';
            $product_description   = !empty(trim($_REQUEST['product_description_checkbox']))   ? trim($_REQUEST['product_description_checkbox'])   : '0';

            $product_price    = !empty(trim($_REQUEST['product_price_checkbox']))   ? trim($_REQUEST['product_price_checkbox'])   : '0';
            $product_image    = !empty(trim($_REQUEST['product_image_checkbox']))   ? trim($_REQUEST['product_image_checkbox'])   : '0';
            $account_info['firstname'] = $firstname;
            $account_info['lastname'] = $lastname;
            $account_info['companyname'] = $companyname;
            $account_info['address'] = $address;
            $account_info['zip'] = $zip;
            $account_info['city'] = $city;
            $account_info['country'] = $country;
            $account_info['phone'] = $phone;
            $account_info['vatnumber'] = $vatnumber;
            

            if (empty($username) && empty($password)) {
                if (!empty($setting) && !empty($setting['username']) && !empty($setting['password'])) {
                    $username = $setting['username'];
                    $password = $setting['password'];
                }
            }
            if (!empty($username) && !empty($password) && !empty($catID)) {
                $setting['email']    = !empty($email) ? $email : $username;
                $setting['username'] = $username;
                if (isset($setting['password'])) {
                    preg_match_all('/\*/', $password, $matches, PREG_OFFSET_CAPTURE);
                    if (count($matches[0]) != strlen($setting['password'])) {
                        $setting['password'] = $password;
                    } else {
                        $setting['password'] = $password;
                    }
                } else {
                    $setting['password'] = $password;
                }
                if (isset($setting['designer_id'])) {
                $setting['designer_id'] = $setting['designer_id'];
                }
                if (isset($setting['dropshipping'])) {
                $setting['dropshipping'] = $setting['dropshipping'];
                }
                
                $setting['catID']    = $catID;
                $setting['lang']     = $lang;
                $setting['varLimit'] = $varlimit;
                $setting['product_status'] = $product_status; // for 1 for publish 0 for drafts products
                 $setting['product_swatches'] = $product_swatches; // for 1 for customize and 0 for default product_swatches
                  $setting['product_title'] = $product_title; 
                $setting['product_description'] = $product_description; 
                $setting['product_price'] = $product_price; 
                $setting['product_image'] = $product_image; 
                $setting['version']  = PLUGIN_VERSION;

                $data = array(
                    'site_name' => get_option("blogname"),
                    'settings'  => $setting,
                    'account_info' => $account_info,
                    'type'      => SHIRTEE_APP
                );
                
                $res_data = $this->execute_curl($data, 'check_auth');                                
                
                if ( isset($res_data['status']) && ($res_data['status'] == 'success') ) {
                    if (isset($res_data['data']['designer_details'])) {
                        $designer_details       = $res_data['data']['designer_details'];
                        $setting['designer_id'] = $designer_details['designer_id'];
                        $full_name = '';
                        if (isset($designer_details['prefix'])) {
                            $full_name = $designer_details['prefix'];
                        }
                        if (isset($designer_details['first_name'])) {
                            $full_name .= !empty($full_name) ? " " . $designer_details['first_name'] : $designer_details['first_name'];
                        }
                        if (isset($designer_details['middle_name'])) {
                            $full_name .= !empty($full_name) ? " " . $designer_details['middle_name'] : $designer_details['middle_name'];
                        }
                        if (isset($designer_details['last_name'])) {
                            $full_name .= !empty($full_name) ? " " . $designer_details['last_name'] : $designer_details['last_name'];
                        }
                        $full_name = addslashes($full_name);
                        $setting['full_name'] = $full_name;

                        
                    }
                    if (!empty($setting)) {
                        $submit = $wpdb->update(
                            $tbl_settings,
                            array(
                                'settings_value'  => serialize($setting)
                            ),
                            array(
                                'settings_name'   => "import_settings"
                            )
                        );
                    } else {
                        $submit = $wpdb->insert(
                            $tbl_settings,
                            array(
                                'settings_name'   => "import_settings",
                                'settings_value'  => serialize($setting)
                            )
                        );
                    }

                    /* Account detail */
                    if(!empty($account_info_detail)){

                        $submit = $wpdb->update(
                            $tbl_settings,
                            array(
                                'settings_value'  => serialize($account_info),
                            ),
                            array(
                                'settings_name'   => "account_info",
                            )
                        );  

                    } else {

                        $submit = $wpdb->insert(
                            $tbl_settings,
                            array(                                
                                'settings_name'   => "account_info",
                                'settings_value'  => serialize($account_info),

                            )
                        );
                    }
                    if (isset($res_data['data']['access_token'])) {
                        if (!empty($access_token)) {
                            $wpdb->update(
                                $tbl_settings,
                                array(
                                    'settings_value' => "{$res_data['data']['access_token']}",
                                ),
                                array(
                                    'settings_name'  => "access_token"
                                )
                            );
                        } else {
                            $wpdb->insert(
                                $tbl_settings,
                                array(
                                    'settings_name'  => "access_token",
                                    'settings_value' => $res_data['data']['access_token']
                                )
                            );
                        }
                    }
                    if (false === $submit) {
                        return wp_send_json(array("status" => 'error', "msg" => __("Error while saving your details due to {$wpdb->last_error}", "shirtee-products-1")));
                    } else {
                        return wp_send_json(array("status" => 'success', "msg" => __("Your details saved successfully...", "shirtee-products-1")));
                    }
                } else {
                    //$fields = $this->shirtee_show_fields();
                    //echo '<pre>'; print_r($settings['password']);
                    return wp_send_json(array("status" => "error", "msg" => __("You entered wrong details...Please check your SHIRTEE store details or contact administrator for same.", "shirtee-products-1")));
                    //return wp_send_json(array("status" => "error", "msg" => __("You entered wrong details...Please check your SHIRTEE store details or contact administrator for same.", "shirtee-products-1"), "fields" => $fields));
                }
            } else {
                return wp_send_json(array("status" => "error", "msg" => __("You entered wrong details...Please check your SHIRTEE store details or contact administrator for same.", "shirtee-products-1")));
            }
            die();
        }

        public function email_resend(){

            $data['resend_email'] = !empty($_REQUEST['resend_email']) ? $_REQUEST['resend_email'] : '';
            $data['counter'] = !empty($_REQUEST['counter']) ? $_REQUEST['counter'] : '';

            $res_data = $this->execute_curl($data, "register_designer_new");
            if( isset($res_data['status']) && ($res_data['status'] == 'error') ){

                return wp_send_json(array("status" => "error", "msg" => __("{$res_data['msg']}", "shirtee-products-1")));

            }
            echo "<pre>"; print_r($res_data);
            die();
        }

        public function change_registration(){

            $data['change_registration'] = !empty($_REQUEST['change_registration']) ? $_REQUEST['change_registration'] : '';

            if($data['change_registration'] == 'change-registration'){
                global $wpdb;
                        $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
                        $wpdb->update(
                            $tbl_settings,
                            array(
                                "settings_value" => "active"
                            ),
                            array(
                                "settings_name"  => "shirtee_register"
                            )
                        );
                        return wp_send_json(array("status" => "success", "msg" => __("Please wait you will be redirect to register page", "shirtee-products-1")));
                die;
            }

            

        }

        /*public function shirtee_show_fields()
        {
            $settings = $this->shirtee_settings();
            if (!empty($settings)) {
                $username = isset($settings['username']) && !empty(trim($settings['username'])) ? trim($settings['username']) : '';
                $password = isset($settings['password']) && !empty(trim($settings['password'])) ? trim($settings['password']) : '';
            }

            $fields  = "<div class='input-box shirtee-credentials'>";
            $fields .= "<div class='input-label'>".__("Shirtee API Username", "shirtee-products-1")."<span>*</span></div>";
            $fields .= "<input required='' id='username' name='username' value='{$username}' class='input-text' placeholder='".__("Username", "shirtee-products-1")."' type='email'>";
            $fields .= "<span id='shirtee-user-error' class='error'>".__("Please enter valid Email ID", "shirtee-products-1")."</span>";
            $fields .= "</div>";
            $fields .= "<div class='input-box shirtee-credentials'>";
            $fields .= "<div class='input-label'>".__("Shirtee API Password", "shirtee-products-1")."<span>*</span></div>";
            $fields .= "<input required='' id='password' name='password' class='input-text' placeholder='".__("Please enter password", "shirtee-products-1")."' type='password'>";
            if (empty($password)) {
                $fields .= "<span class='error show'>".__("Please contact your administrator for password", "shirtee-products-1")."</span>";
            }
            $fields .= "<span id='shirtee-pswd-error' class='error'>".__("Please enter valid Password", "shirtee-products-1")."</span>";
            $fields .= "</div>";
            return $fields;
        }*/
        public function shirtee_show_fields()
        {
            $settings = $this->shirtee_settings();
            if (!empty($settings)) {
                $username = isset($settings['username']) && !empty(trim($settings['username'])) ? trim($settings['username']) : '';
                $password = isset($settings['password']) && !empty(trim($settings['password'])) ? trim($settings['password']) : '';
            }
            $access_token = $this->shirtee_settings('access_token');
            $is_migrating = $this->shirtee_settings('is_migrated');
            $email        = $username = $password = $catID = "";
            $account_info = unserialize($this->shirtee_settings('account_info'));
           // echo "<pre>"; print_r($account_info); die;
            $varLimit     = 200;
            $implang      = 'de';
            if (!empty($settings)) {
                    $username = isset($settings['username']) && !empty($settings['username']) ? $settings['username'] : '';
                    $password = isset($settings['password']) && !empty($settings['password']) ? $settings['password'] : '';
                    $catID    = isset($settings['catID'])    && !empty($settings['catID'])    ? $settings['catID']    : '';
                    if( is_array($catID) )
                    {
                         if( count($catID) == 1 )
                         {
                             $catID = $catID[0]; 
                         } 
                        
                    } else {
                        $catID = $catID;
                    }

                    $email    = isset($settings['email'])    && !empty($settings['email'])    ? $settings['email']    : '';
                    $varLimit = isset($settings['varLimit']) && !empty($settings['varLimit']) ? $settings['varLimit'] : 200;
                    $implang  = isset($settings['lang'])     && !empty($settings['lang'])     ? $settings['lang']     : 'de';

                    /* Account Details*/
                    
                    $first_name = isset($account_info['firstname'])    && !empty($account_info['firstname'])    ? $account_info['firstname']    : '';
                    $last_name = isset($account_info['lastname'])    && !empty($account_info['lastname'])    ? $account_info['lastname']    : '';
                    $company_name = isset($account_info['companyname'])    && !empty($account_info['companyname'])    ? $account_info['companyname']    : '';
                    $address = isset($account_info['address'])    && !empty($account_info['address'])    ? $account_info['address']    : '';                    
                    $zip_code = isset($account_info['zip'])    && !empty($account_info['zip'])    ? $account_info['zip']    : '';
                    $city = isset($account_info['city'])    && !empty($account_info['city'])    ? $account_info['city']    : '';
                    $country = isset($account_info['country'])    && !empty($account_info['country'])    ? $account_info['country']    : '';
                    $phone = isset($account_info['phone'])    && !empty($account_info['phone'])    ? $account_info['phone']    : '';
                    $vat_number = isset($account_info['vatnumber'])    && !empty($account_info['vatnumber'])    ? $account_info['vatnumber']    : '';

                    if ($password != '') {
                        $pswd = str_repeat("*", strlen($password));
                        $placeholder = $pswd;
                    }
                }
                $fields ="<div class='field-row'>
                        <div class='field-col'>
                            <div class='input-box shirtee-credentials'>
                                <div class='input-label'>".__('Shirtee API Username', 'shirtee-products-1')."<span>*</span></div>
                                <input required='' id='username' name='username' value='{$username}' class='input-text' placeholder='Username' type='email' />
                                <span id='shirtee-user-error' class='error'>".__('Please enter valid Email ID', 'shirtee-products-1')."</span>
                            </div>
                        </div>
                        <div class='field-col'>
                            <div class='input-box shirtee-credentials'>
                                <div class='input-label'>".__('Shirtee API Password', 'shirtee-products-1')."<span>*</span></div>
                                <input required='' id='password' name='password' class='input-text' placeholder='{$placeholder}' type='password' />";
                                if ($password == '') {
                                    $fields .= "<span class='error show'>".__('Please contact your administrator for password', 'shirtee-products-1')."</span>";
                                }
                                $fields .= "<span id='shirtee-pswd-error' class='error'>".__('Please enter valid Password', 'shirtee-products-1')."</span>
                            </div>
                        </div>
                    </div>";
            $fields .="<div class='field-row ex-space'>
                                            <div class='field-col'>
                                                <div class='input-label'>".__("Select your Shirtee Shop ID", "shirtee-products-1")."<span>*</span></div>";
                                           if( ( is_array($catID) ) && (count($catID) != 1) && ($catID > 1) )
                                                     {  
                                                         $fields .= "<select id='catID' name='catID' class='select-text'>
                                                         <option value=''>".__("Please Select Shirtee Shop ID", "shirtee-products-1")."</option>";
                                                         foreach($catID as $cat){
                                                         $fields .= "<option value=".$cat.">".$cat."</option>";
                                                            }
                                                         $fields .= "</select>
                                             <span id='shirtee-cat-error' class='error show'>".__("Please Select Shirtee Shop ID", "shirtee-products-1")."</span>";
                                                                                                              
                                                }  else { 
                                       $fields .= "<input required='' id='catID' name='catID' value='{$catID}' class='input-text' placeholder='Shirtee Shop ID' type='text' />";
                                            if ($catID = '') {
                                            $fields .= "<span id='shirtee-cat-error' class='error show'>".__("Please enter Shirtee Shop ID", "shirtee-products-1")."</span>";
                                        }
                                                }
                                            $fields .= "</div>
                                        <div class='field-col'>
                                        <div class='input-label'>".__("Language", "shirtee-products-1")."</div>
                                        <select id='implang' name='implang' class='select-text'>
                                            <option value='de' {$implang} == 'de' ? selected='selected ': ''>".__('German', 'shirtee-products-1')." </option>
                                             <option value='en' {$implang} == 'en' ? selected='selected' : '' >".__("English", "shirtee-products-1")."</option>
                                            <option value='da' {$implang} == 'da' ? selected='selected' : '' >".__("Danish", "shirtee-products-1")."</option>
                                            <option value='es' {$implang} == 'es' ? selected='selected' : '' > ".__("Spanish", "shirtee-products-1")."</option>
                                            <option value='fi' {$implang} == 'fi' ? selected='selected' : '' > ".__("Finnish", "shirtee-products-1")."</option>
                                            <option value='fr' {$implang} == 'fr' ? selected='selected' : '' > ".__("French", "shirtee-products-1")."</option>
                                            <option value='it' {$implang} == 'it' ? selected='selected' : '' > ".__("Italian", "shirtee-products-1")."</option>
                                            <option value='nl' {$implang} == 'nl' ? selected='selected' : '' > ".__("Dutch", "shirtee-products-1")."</option>
                                            <option value='nb' {$implang} == 'nb' ? selected='selected' : '' > ".__("Norwegian bokmål", "shirtee-products-1")."</option>
                                            <option value='pl' {$implang} == 'pl' ? selected='selected' : '' > ".__("Polish", "shirtee-products-1")."</option>
                                            <option value='pt' {$implang} == 'pt' ? selected='selected' : '' > ".__("Portuguese", "shirtee-products-1")."</option>
                                            <option value='sv' {$implang} == 'sv' ? selected='selected' : '' > ".__("Swedish", "shirtee-products-1")."</option>
                                        </select>
                                        <span>".__("Language of the Shirtee product content.", "shirtee-products-1")."</span>
                                        </div>
                                    </div></div>
                                    <div class='input-box'>
                                        <div class='field-row'>
                                            <div class='field-col'>
                                                <div class='input-label'>".__('First Name', 'shirtee-products-1')."<span>*</span></div>
                                                <div class='input-group'>
                                                    <input required='' id='first_name' autocomplete='none' name='first_name' class='input-text' placeholder='First Name' type='text' value='{$first_name}' />
                                                </div>
                                                <span id='shirtee-fname-error' class='error'>".__('Please enter your first name', 'shirtee-products-1')."</span>
                                            </div>
                                            <div class='field-col'>
                                                <div class='input-label'>".__('Last Name', 'shirtee-products-1')."<span>*</span></div>
                                                <div class='input-group'>
                                                    <input required='' id='last_name' autocomplete='none' name='last_name' class='input-text' placeholder='Last Name' type='text' value='{$last_name}' />
                                                </div>
                                                <span id='shirtee-lname-error' class='error'>".__('Please enter your Last name', 'shirtee-products-1')."</span>
                                            </div>
                                        </div>
                                    </div>
                                    <div class='input-box'>
                                        <div class='field-row'>
                                            <div class='input-label'>".__('Company (optional)', 'shirtee-products-1')."</div>
                                            <input id='company_name' name='company_name' value='{$company_name}' class='input-text' placeholder='Company' type='text' /> 
                                        </div>                                       
                                    </div>
                                    <div class='input-box'>
                                        <div class='field-row'>
                                            <div class='input-label'>".__('Address', 'shirtee-products-1')."<span>*</span></div>
                                            <div class='input-group'>
                                                <input id='address' name='address' value='{$address}' class='input-text' placeholder='Address' type='text' />                                        
                                            </div> 
                                            <span id='shirtee-address-error' class='error'>".__('Please enter your Address', 'shirtee-products-1')."</span>
                                        </div>
                                    </div>
                                    <div class='input-box'>
                                        <div class='field-row'>
                                            <div class='field-col'>
                                                <div class='field-row'>
                                                    <div class='field-col'>
                                                        <div class='input-label'>".__('ZIP Code', 'shirtee-products-1')."<span>*</span></div>
                                                        <div class='input-group'>
                                                            <input id='zip_code' name='zip_code' value='{$zip_code}' class='input-text' placeholder='Zip' type='text' />                                        
                                                        </div>
                                                        <span id='shirtee-zipcode-error' class='error'>".__('Please enter your ZIP code', 'shirtee-products-1')."</span>
                                                    </div>
                                                    <div class='field-col'>
                                                        <div class='input-label'>".__('City', 'shirtee-products-1')."<span>*</span></div>
                                                        <div class='input-group'>
                                                            <input id='city' name='city' value='{$city}' class='input-text' placeholder='City' type='text' />                                        
                                                        </div>
                                                        <span id='shirtee-city-error' class='error'>".__('Please enter your City', 'shirtee-products-1')."</span>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class='field-col'>
                                                <div class='input-label'>".__('Country', 'shirtee-products-1')."</div>
                                                <select id='country' name='country' class='select-text'>";
                                                    foreach ($countryArray as $key => $value) { 
                                                        $selected = $country == $key ? "selected='selected'" :'';
                                                        $fields .= "<option value=".$key." ".$selected.">".$value."</option>";
                                                    }
                                                $fields .= "</select>
                                                <!-- <span id='shirtee-country-error' class='error'>".__('Please select your Country', 'shirtee-products-1')."</span> -->
                                            </div>
                                        </div>
                                    </div>
                                    <div class='input-box'>
                                        <div class='field-row'>
                                            <div class='field-col'>
                                                <div class='input-label'>".__('Phone', 'shirtee-products-1')."<span>*</span></div>
                                                <div class='input-group'>
                                                    <input id='phone' name='phone' value='{$phone}' class='input-text' placeholder='Phone' type='text' />                                        
                                                </div>
                                                <span id='shirtee-phone-error' class='error'>".__('Please enter your Phone', 'shirtee-products-1')."</span>
                                            </div>
                                            <div class='field-col'>
                                                <div class='input-label'>".__('VAT Number', 'shirtee-products-1')."</div>
                                                <div class='input-group'>
                                                    <input id='vat_number' name='vat_number' value='{$vat_number}' class='input-text' placeholder='VAT Number' type='text' />                                        
                                                </div>
                                                <!-- <span id='shirtee-vatnumber-error' class='error'>".__('Please enter your VAT Number', 'shirtee-products-1')."</span> -->
                                            </div>
                                        </div>
                                        <div class='field-row'>
                                            
                                            <div class='field-col'>
                                                <div class='input-label'>".__('Variation Limits', 'shirtee-products-1')."</div>
                                                <input id='varlimit' name='varlimit' value='{$varLimit}' class='input-text' placeholder='Variation Limits' type='text' />
                                                <span>".__('Fix for issue where too many variations causes the front end to not pre-load all variations and rely on AJAX.', 'shirtee-products-1')."</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>";
            return $fields;
        }
        public function woo_product_schedule_process()
        {
            if (!$this->is_shirtee_plugin_activate()) {
                $message['i_error'] = "Shirtee Products Importer is not installed or activated in your site.Please install or activate plugin.";
                return wp_send_json($message);
            }
            if (!$this->is_shirtee_required_plugin_activate()) {
                $message['i_error'] = "Woocommerce is not installed or activated in your site.Please install or activate woocommerce to use Shirtee Products Importer features.";
                return wp_send_json($message);
            }
            global $wpdb;
            $import_cron = "{$wpdb->prefix}shirtee_import_product_insert_cron";
            $shirtee_import_products = "{$wpdb->prefix}shirtee_import_products";
            
            
            $message  = $IDS = $mage_products = array();

            $UF = $US = $IF = $IS = $p = 0;
            $product_data = $_REQUEST['product_data'];
            if (!empty($product_data)) {
                foreach ($product_data as $products) {
                    $mage_products[$p]['product_id']  = $productId   = $products['product_id'];
                    $mage_products[$p]['prod_status'] = $prod_status = "insert";
                    $mage_products[$p]['woo_id']      = $WpProductID = 0;
                    $mage_products[$p]['url']         = '';
                    
                    $productinfo = $wpdb->get_row("SELECT ID,is_warehouse FROM {$shirtee_import_products} WHERE product_mage_id = '{$productId}'");
                    if (!empty($productinfo)) {
                        if( $productinfo->is_warehouse == 1 ){
                                $mage_products[$p]['warehouse'] = 1;
                        }
                    }
                    
                    $publish = $products['publish'];
                    if (strpos($productId, '#') !== false) { //For Update Product
                        $products_IDs = explode("#", $productId);
                        $mage_products[$p]['product_id']  = $productId   = !empty($products_IDs[1]) ? $products_IDs[1] : "";
                        $mage_products[$p]['woo_id']      = $WpProductID = !empty($products_IDs[2]) ? $products_IDs[2] : 0;
                        $mage_products[$p]['prod_status'] = $prod_status = "update";
                        $mage_products[$p]['url']         = get_the_permalink($WpProductID);
                    }
                    if (empty($productId)) {
                        return wp_send_json(array("i_error" => __("Shirtee Product Id missing...", "shirtee-products-1")));
                    }
                    $update = $wpdb->get_row("SELECT ID FROM {$import_cron} WHERE mage_id = '{$productId}'");
                    if (!empty($update)) {
                        $query = $wpdb->update(
                            $import_cron,
                            array(
                                "woo_id"         => $WpProductID,
                                "product_status" => $prod_status,
                                "publish"        => $publish,
                                "updated_at"     =>  current_time('mysql'),
                                "status"         => 1,
                            ),
                            array(
                                "ID"             => $update->ID
                            )
                        );
                    } else {
                        $query = $wpdb->insert(
                            $import_cron,
                            array(
                                "mage_id"        => $productId,
                                "woo_id"         => $WpProductID,
                                "product_status" => $prod_status,
                                "publish"        => $publish,
                                "created_at"     =>  current_time('mysql'),
                                "updated_at"     =>  current_time('mysql'),
                                "status"         => 1,
                            )
                        );
                    }
                    if (false === $query) {
                        if ($WpProductID != 0) {
                            $UF++;
                        } else {
                            $IF++;
                        }
                    } else {
                        if ($WpProductID != 0) {
                            $US++;
                        } else {
                            $IS++;
                        }
                        $IDS[] = $productId;
                    }
                    $p++;
                }
                if (!empty($mage_products)) {
                    $data = array(
                        "mage_ids"  => $mage_products,
                    );
                    $response = $this->execute_curl($data, "schedule_product");
                }
                if ($IF > 0) {
                    $message['i_error']   = $IF . __(' Shirtee products not moved to Import queue.', 'shirtee-products-1');
                }
                if ($IS > 0) {
                    $message['i_success'] = $IS . __(' Shirtee products moved to Import queue.', 'shirtee-products-1');
                }
                if ($UF > 0) {
                    $message['u_error']   = $UF . __(' Shirtee products not moved to Update queue.', 'shirtee-products-1');
                }
                if ($US > 0) {
                    $message['u_success'] = $US . __(' Shirtee products moved to Update queue.', 'shirtee-products-1');
                }
                $message['ids'] = $IDS;
            } else {
                $message['i_error'] = __('Oops! No product(s) select for schedule.', 'shirtee-products-1');
            }
            return wp_send_json($message);
        }

        public function fetch_data()
        {
            if (!$this->is_shirtee_plugin_activate()) {
                $message = array("status" => "error", "msg" => __("Shirtee Products Importer is not installed or activated in your site.Please install or activate plugin.", "shirtee-products-1"));
                return wp_send_json($message);
            }
            if (!$this->is_shirtee_required_plugin_activate()) {
                $message = array("status" => "error", "msg" => __("Woocommerce is not installed or activated in your site.Please install or activate woocommerce to use Shirtee Products Importer features.", "shirtee-products-1"));
                return wp_send_json($message);
            }
            $this->fetch_products_details($_REQUEST['insert']);
            die();
        }

        public function fetch_products_details($insert)
        {
            if ($insert === false) {
                return wp_send_json(array("status" => "error", "msg" => __("Access Denied...", "shirtee-products-1")));
            }

            $res_data = $this->execute_curl('', 'sync_data');
            if ($res_data['status'] == "success") {
                global $wpdb;
                $tbl_product_list = "{$wpdb->prefix}shirtee_import_products";
                $result   = $res_data['data'];
                if (!empty($result)) {
                    foreach ($result as $r) {
                        $product_id = $r['product_id'];
                        $proInsed   = $wpdb->get_row("SELECT * FROM {$tbl_product_list} WHERE product_mage_id = {$product_id}");
                        if (!empty($proInsed)) {
                            if (!in_array($proInsed->status, array(2, 3)) && ($proInsed->product_woo_id == '' || $proInsed->product_woo_id == 0)) {
                                $wpdb->query("UPDATE {$tbl_product_list} SET status = 0 WHERE product_mage_id = {$product_id}");
                            }
                        } else {
                            $wpdb->query("INSERT INTO {$tbl_product_list}( `product_mage_id`,`status` )VALUES('{$product_id}', 0)");
                        }
                    }
                    return $this->products_list_table();
                } elseif (empty($result) && !isset($result['status'])) {
                    return wp_send_json(array("status" => "error", "msg" => __("<p>No Any Product Founds from the Shirtee Store...</p>", "shirtee-products-1")));
                } else {
                    return wp_send_json($result);
                }
            } else {
                return wp_send_json(array("status" => "error", "msg" => __($res_data['msg'], "shirtee-products-1")));
            }
        }

        public function products_list()
        {
            $this->products_list_table($_REQUEST['limit'], $_REQUEST['search_key'], $_REQUEST['page_num'], $_REQUEST['status'], $_REQUEST['product_type']);
            die();
        }

        public function products_list_table($limit = 10, $search_key = '', $pagenum = 1, $status = 'all', $product_type = 'all')
        {
            global $wpdb;
            $settings     = $this->shirtee_settings();


            //update stock
            $qty = "113";
            $post_id = 118; 
            $new_stock = wc_update_product_stock($post_id, $qty, 'set', false);
            //update stock end

            $woo_token = $this->shirtee_settings('woo_token'); //woo_token
            if ( empty($woo_token) ) { //woo_token
                exit(wp_safe_redirect(admin_url('admin.php?page=add-settings'))); //woo_token
            } //woo_token
            $tbl_product_list = "{$wpdb->prefix}shirtee_import_products";
            $tbl_schedule     = "{$wpdb->prefix}shirtee_import_product_insert_cron";
            $offset           = ($pagenum - 1) * $limit;
            $select           = "SELECT * FROM {$tbl_product_list} WHERE status NOT IN( 0,3 )";
            $checkcron        = $wpdb->get_var("SELECT count( ID ) FROM {$tbl_product_list} WHERE status = 0");
            $select_cond      = $search_key != '' ? " AND product_type LIKE '%{$search_key}%' OR product_mage_id LIKE '%{$search_key}%' OR product_sku LIKE '%{$search_key}%'" : "";
            if ($status == '0') {
                $select_cond .= " AND product_woo_id != 0";
            } elseif ($status == '1') {
                $select_cond .= " AND product_woo_id = 0";
            }
            if ($product_type != 'all' && $product_type != '') {
                $select_cond .= " AND product_title = '{$product_type}'";
            }
            $import    = shirtee_products_count('0', $product_type);
            $notimport = shirtee_products_count('1', $product_type);
            $all       = shirtee_products_count('', $product_type); ?>
            <script type='text/javascript'>
                jQuery('#import-filter li:eq( 0 ) a').text('All <?php echo $all; ?>');
                jQuery('#import-filter li:eq( 1 ) a').text('Imported <?php echo $import; ?>');
                jQuery('#import-filter li:eq( 2 ) a').text('Not Imported <?php echo $notimport; ?>');
            </script>
            <?php
            $select .= $select_cond;
            $select .= " LIMIT $offset , $limit";
            $total   = $wpdb->get_var("SELECT COUNT('ID') FROM {$tbl_product_list} WHERE status NOT IN( 0,3 ) {$select_cond}");
            $num_of_pages = ceil($total / $limit);
            $allProDatas  = $wpdb->get_results($select); ?>
             <div class="table-div">
            <div class="table-main-wrap">
                <table class="product-list">
                    <thead>
                        <tr class="border-top-wrap">
                            <th class="checkbox-wrap">
                                <div class="custom-radio-button publish-radio-btn">
                                    <label class="input-radio-button">
                                        <input class="radio-input product-list-all" type="checkbox" name="product-list-all" id="product-list-all">
                                        <i class="icon-radio"></i>
                                    </label>
                                </div>
                            </th>
                            
                            <th><?php _e("Product", "shirtee-products-1"); ?></th>
                            <!-- <th><?php _e("SKU", "shirtee-products-1"); ?></th>-->
                            <!-- <th></th> -->
                            <th></th>
                            <th><?php _e("Status", "shirtee-products-1"); ?></th> 
                            <th><?php _e("Variations", "shirtee-products-1"); ?></th>
                            <th class="wordpress-id-th"><?php _e("Wordpress ID", "shirtee-products-1"); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        if (!empty($checkcron)) {
                            _e("<tr class='inprogress-data'><td colspan='8'><div class='pro_inprogress'><div class='loader'></div><div class='loader_text'>{$checkcron} Products are in progress...</div></div></td></tr>", "shirtee-products-1");
                        } 
                        if (!empty($allProDatas)) {
                            foreach ($allProDatas as $allProData) {

                                $status = $allProData->product_woo_id != 0 ? get_post_status($allProData->product_woo_id) : '';
                                $insertcronID = $wpdb->get_row("SELECT * FROM {$tbl_schedule} WHERE mage_id = '{$allProData->product_mage_id}' AND status != 0");                              
                                ?>
                                <tr class="records">
                                    <td class="checkbox-wrap data-add" id="data-<?php echo $allProData->product_mage_id; ?>">
                                        <?php if (!empty($insertcronID)) { ?>
                                            <div class="inprogress">
                                                <div class="loader"></div>
                                            </div>
                                        <?php } elseif ($allProData->status == 2) { ?>
                                            <div class="removedProduct">
                                                
                                                 <label class="input-radio-button">
                                                    <input class="radio-input single-imppro" id="proimp-<?php echo $allProData->product_mage_id; ?>" type="checkbox" name="product-list[]" value="<?php echo $allProData->product_woo_id != 0 ? $allProData->ID . '#' . $allProData->product_mage_id . '#' . $allProData->product_woo_id : $allProData->product_mage_id; ?>">
                                                    <i class=""></i>
                                                    <i class="icon-radio"></i>
                                                </label>
                                            </div>
                                        <?php } else { ?>
                                            <div class="custom-radio-button">
                                                <label class="input-radio-button">
                                                    <input class="radio-input single-imppro" id="proimp-<?php echo $allProData->product_mage_id; ?>" type="checkbox" name="product-list[]" value="<?php echo $allProData->product_woo_id != 0 ? $allProData->ID . '#' . $allProData->product_mage_id . '#' . $allProData->product_woo_id : $allProData->product_mage_id; ?>">
                                                    <i class="icon-radio"></i>
                                                </label>
                                            </div>
                                        <?php } ?>
                                    </td>
                                
                                     <td class="data-type align-left product-name-td"><?php echo $allProData->product_woo_id != '' && $allProData->product_woo_id != 0 ? "<p class='product-name'><a href='" . get_the_permalink($allProData->product_woo_id) . "' target='_blank' title='" . $allProData->product_type . "'><strong>" . $allProData->product_type . "</strong></a></p>" : $allProData->product_type; ?>
                                     <span class="tag-sapn"><?php echo $allProData->product_sku; ?></span></td>
                                    
                                    <td class="data-title align-left"><?php echo $allProData->product_title; ?></td>
                                  <?php if( isset($insertcronID->status) && ($insertcronID->status==1) ){ ?>
                                        <td class="data-title status-td"><span class="blue">Scheduled</span></td>
                                  <?php } else if ($status == 'publish' || $status == 'draft' || (!empty($insertcronID) && $insertcronID->publish == 1 && $insertcronID->publish == 0)) { ?>
                                        <td class="data-title status-td"><span class="green">Synced</span></td>
                                    <?php } else { ?>
                                        <td class="data-title status-td"><span class="orrage">Not Synced</span></td>
                                  <?php  }?>

                                    <td class="data-var"><?php echo $allProData->product_variations; ?></td>
                                    <td id="woo_id_<?php echo $allProData->product_mage_id; ?>" class="notification data-wid">
                                        <span>
                                            <?php echo $allProData->product_woo_id != 0 ? "<a href='post.php?post=" . $allProData->product_woo_id . "&action=edit' target='_blank' title='" . get_the_title($allProData->product_woo_id) . "'>" . $allProData->product_woo_id . "</a>" : "-";  ?>
                                        </span>
                                        <?php if ($allProData->status == 2 && $allProData->product_woo_id == 0 && $allProData->product_woo_id == '') {
                                            echo "<span class='display_not' id='display-" . $allProData->product_mage_id . "'><i class='fa fa-exclamation-circle'></i><a hreaf='javascript:void(0);' id='remove-" . $allProData->product_mage_id . "' title='Remove product from list' class='remove'>Remove</a></span>";
                                            echo "<span class='warning' id='warning-" . $allProData->product_mage_id . "'>This product will not longer to import into your site due to it was removed from your Shirtee store.<i class='fa fa-close close_warn'></i></span>";
                                        } elseif ($allProData->status == 2 && $allProData->product_woo_id != 0 && $allProData->product_woo_id != '') {
                                            echo "<span class='display_not' id='display-" . $allProData->product_mage_id . "'><i class='fa fa-exclamation-circle'></i><a hreaf='javascript:void(0);' title='Remove product from list' id='remove-" . $allProData->product_mage_id . "' class='remove'>Remove</a></span>";
                                            echo "<span class='warning' id='warning-" . $allProData->product_mage_id . "'>This product was removed from your Shirtee store. Please remove it from woocommerce. Orders of this product not be longer import into your Shirtee store.<i class='fa fa-close close_warn' id='close-" . $allProData->product_mage_id . "'></i></span>";
                                        } elseif ($status != 'publish' && $status != '') {
                                            echo "<span class='display_not' id='display-" . $allProData->product_mage_id . "'><i class='fa fa-exclamation-circle'></i></span>";
                                            echo "<span class='warning' id='warning-" . $allProData->product_mage_id . "'>Your post is in <strong>" . $status . "</strong> status. Please make it to <strong>publish</strong> to display it at front-end.<i class='fa fa-close close_warn' id='close-" . $allProData->product_mage_id . "'></i></span>";
                                        } ?>
                                    </td>
                                </tr>
                            <?php }
                        } else {
                            if( isset($settings['dropshipping']) && ($settings['dropshipping']=="yes") ){
                                _e('<tr><td colspan="8" class="no_records">No Product Founds...You can add product from left menu in Shirtee products > Add products</td></tr>', "shirtee-product-importer");
                            } else {
                                _e('<tr><td colspan="8" class="no_records">No Product Founds...</td></tr>', "shirtee-product-importer");
                            }
                        } //main endif completed
                        ?>
                    </tbody>
                </table>
            </div>
        
            <?php if ($allProDatas && $num_of_pages > 1) { ?>
                <div class="pagination-wrap" id="product-pagination">
                    <?php $this->shirtee_pagination($num_of_pages, $pagenum); ?>
                </div>
            </div>
            <?php }
        }

        /*Products Count*/
        public function products_count($status = 'all', $product_type = 'all')
        {
            global $wpdb;
            $tbl_product_list = $wpdb->prefix . "shirtee_import_products";
            $select       = "SELECT COUNT('ID') FROM $tbl_product_list WHERE status NOT IN( 0,3 )";
            if ($status == '0') {
                $select  .= " AND product_woo_id != 0";
            } elseif ($status == '1') {
                $select  .= " AND product_woo_id = 0";
            }
            if ($product_type != 'all' && $product_type != '') {
                $select  .= " AND product_title = '" . $product_type . "'";
            }
            $products = $wpdb->get_var($select);
            return $products;
        }

        public function order_list()
        {
            $this->order_listing($_REQUEST['limit'], $_REQUEST['search_key'], $_REQUEST['page_num']);
            die();
        }

        public function order_listing($limit = 10, $search_key = '', $paged = 1)
        {
            global $wpdb;
            $order_table  = $wpdb->prefix . "shirtee_import_woo_orders";
            $offset       = ($paged - 1) * $limit;
            $order_query  = "SELECT * FROM $order_table";
            $order_cond   = $search_key != '' ? " WHERE woo_order_email LIKE '%" . $search_key . "%' OR woo_shirtee_id  LIKE '%" . $search_key . "%' OR woo_order_id  LIKE '%" . $search_key . "%'" : "";
            $order_query .= $order_cond;
            $total_query  = "SELECT COUNT('ID') FROM $order_table";
            $total_query .= $order_cond != '' ? " $order_cond" : '';
            $total = $wpdb->get_var($total_query);
            $num_of_pages = ceil($total / $limit);
            $order_query .= " ORDER BY ID DESC LIMIT $offset , $limit";
            $order = $wpdb->get_results($order_query); ?>
            <div class="table-main-wrap">
                <table class="product-list">
                    <thead>
                        <tr class="border-top-wrap">
                            <th><?php _e("Order ID", "shirtee-products-1"); ?></th>
                            <th><?php _e("Shirtee-ID", "shirtee-products-1"); ?></th>
                            <th><?php _e("Email", "shirtee-products-1"); ?></th>
                            <th><?php _e("Date", "shirtee-products-1"); ?></th>
                            <th><?php _e("Status", "shirtee-products-1"); ?></th>
                            <th><?php _e("Total", "shirtee-products-1"); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        if (!empty($order)) {
                            for ($o = 0; $o < count($order); $o++) { ?>
                                <tr>
                                    <td>
                                        <a href="<?php echo admin_url(); ?>post.php?post=<?php echo $order[$o]->woo_order_ID; ?>&action=edit" class="order-view">
                                            <strong>
                                                #<?php echo $order[$o]->woo_order_ID; ?>
                                            </strong>
                                        </a>
                                    </td>
                                    <td class="order_status">
                                        <?php if ($order[$o]->status != 1 && $order[$o]->woo_shirtee_id == '' && $order[$o]->woo_shirtee_error == '') {
                                            echo '<div class="inprogress order_loader">';
                                            echo '<div class="loader"></div>';
                                            echo '</div>';
                                        } elseif (!empty($order[$o]->woo_shirtee_error) && empty($order[$o]->woo_shirtee_id) ) {
                                            echo "<span>" . $order[$o]->woo_shirtee_error."</span>";
                                        } else {
                                            echo "<span>" . $order[$o]->woo_shirtee_id != '' ? $order[$o]->woo_shirtee_id : '-' . "</span>";
                                        } ?>
                                    </td>
                                    <td><?php echo $order[$o]->woo_order_email; ?></td>
                                    <td><?php echo date('d-m-Y h:i:s', strtotime($order[$o]->woo_order_date)); ?></td>
                                    <td class="submitdelete"><strong><?php echo ucwords($order[$o]->woo_order_status); ?></strong></td>
                                    <td><?php echo $order[$o]->woo_order_price . " " . get_woocommerce_currency(); ?></td>
                                </tr>
                            <?php }
                        } else {
                            _e('<tr><td colspan="6" class="no_records">No Order Founds...</td></tr>', "shirtee-products-1");
                        } ?>
                    </tbody>
                </table>
            </div>
            <?php
            if ($num_of_pages > 1) { ?>
                <div class="pagination-wrap" id="order-pagination">
                    <?php $this->shirtee_pagination($num_of_pages, $paged); ?>
                </div>
            <?php }
            wp_reset_query();
        }

        /*Shirtee Pagination*/
        public function shirtee_pagination($pages = '', $paged = 1, $range = 2)
        {
            $showitems = ($range * 2) + 1;
            if (1 != $pages) {
                echo '<div class="pagination" id="shirtee-pagination">';
                if ($paged > 2 && $paged > $range + 1 && $showitems < $pages) {
                    echo '<a class="prev page-numbers" href="javascript:void(0);" data-value="1" title="First"> << </a>';
                }
                if ($paged > 1) {
                    echo '<a class="prev page-numbers" href="javascript:void(0);" data-value="' . ($paged - 1) . '"> < </a>';
                }
                for ($i = 1; $i <= $pages; $i++) {
                    if (1 != $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems)) {
                        if ($paged == $i) {
                            echo '<span aria-current="page" class="page-numbers current">' . $i . '</span>';
                        } else {
                            echo '<a class="page-numbers" href="javascript:void(0);" data-value="' . $i . '">' . $i . '</a>';
                        }
                    }
                }
                if ($paged < $pages) {
                    echo '<a class="next page-numbers" href="javascript:void(0);" data-value="' . ($paged + 1) . '">></a>';
                }
                if ($paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages) {
                    echo '<a class="next page-numbers" href="javascript:void(0);" data-value="' . $pages . '" title="Last"> >> </a>';
                }
                    echo '<div class="jump_page result-wrap">';
                        echo '<label for="jump_page_number">Go to Page</label>';
                        echo '<select name="jump_page_number" id="jump_page_number">';
                for ($i = 1; $i <= $pages; $i++) {
                    $selcted = $paged == $i ? "selected=selected" : '';
                    echo '<option value="' . $i . '" ' . $selcted . '>' . $i . '</option>';
                }
                        echo '</select>';
                    echo '</div>';
                echo '</div>';
            }
        }

        public function woo_remove_shirtee_product()
        {
            global $wpdb;
            $product_mage_id = $_REQUEST['id'] != '' ? $_REQUEST['id'] : '';
            $product_list    = $wpdb->prefix . "shirtee_import_products";
            $mage_products   = array();
            if (empty($product_mage_id)) {
                return wp_send_json(array("type" => "error", "msg" => "Product ID not founds..."));
            }
            foreach ($product_mage_id as $product) {
                if (strpos($product, "#") !== false) {
                    $product_id = explode("#", $product);
                    $remove_id  = $product_id[1];
                    $woo_id     = $product_id[2];
                } else {
                    $remove_id  = $product;
                    $woo_id     = 0;
                }
                $get_woo  = $wpdb->get_row("SELECT product_sku FROM {$product_list} WHERE product_mage_id = {$remove_id}");
                $products = $wpdb->get_row("DELETE FROM {$product_list} WHERE product_mage_id = {$remove_id}");
                if (!is_wp_error($products)) {
                    if ($woo_id != 0 && !is_null(get_post($woo_id))) {
                        remove_product_info($remove_id, $woo_id);
                    }
                    $mage_products['mage_ids'][] = $remove_id;
                    $message['success'][] = $get_woo->product_sku.__(" was removed successfully...", "shirtee-products-1");
                    $message['remove'][]  = $remove_id;
                } else {
                    $message['error'][]   = $get_woo->product_sku.__(" was not removed...", "shirtee-products-1");
                    $message['not'][]     = $remove_id;
                }
            }
            if (isset($mage_products)) {
                $response = $this->execute_curl($mage_products, 'remove_products');
            }
            return wp_send_json($message);
        }

        public function manage_order_to_magento($order_id)
        {
            global $wpdb;
            $order_table     = $wpdb->prefix . "shirtee_import_woo_orders";
            $order           = new WC_Order($order_id);
            $order_data      = array();
            $orderCollection = '';
            $orderdata       = $order->get_data();
            $order_status    = $order->get_status();
            $oldorders       = $wpdb->get_row("SELECT * FROM " . $order_table . " WHERE woo_order_ID = " . $order_id);            
            if (!empty($oldorders)) {
                $insertOrder = $wpdb->update(
                    $order_table,
                    array(
                        'woo_order_status' => $order_status,
                    ),
                    array(
                        'woo_order_ID'     => $order_id,
                    )
                );
            } else {
                $exported = get_post_meta($order_id, 'export_success', true);
                if ($exported != true) {
                    if (in_array($order_status, array('processing', 'completed'))) {
                        $items = $order->get_items();
                        $price = 0;
                        $billing_email  = $orderdata['billing']['email'];
                        $date_created   = $orderdata['date_created']->date('Y-m-d H:i:s');
                        $variation_id   = '';
                        $total_price    = $orderdata['total'];
                        foreach ($items as $item_id => $item) {
                            $sku = "";
                            $checkWoo = get_post_meta($item['product_id'], 'product_imported', true);
                            if (!empty($item['variation_id'])) {
                                $variation_id = $item['variation_id'];
                            }
                            if ($checkWoo == true) {
                                $qty         = wc_get_order_item_meta($item_id, '_qty', true);
                                $custom_text = wc_get_order_item_meta($item_id, 'Custom Field', true);
                                if (!empty(trim($custom_text))) {
                                    $order_data[$item['product_id']][] = array("product_id" => $item['product_id'], "variation_id" => $variation_id, "qty" => $qty, "is_browse" => 0, "custom_field" => trim($custom_text));
                                } else {
                                    $order_data[$item['product_id']][] = array("product_id" => $item['product_id'], "variation_id" => $variation_id, "qty" => $qty, "is_browse" => 0);
                                }
                                $price = $price + $item->get_total();
                            } else {
                                if (!empty($variation_id)) {
                                    $sku = get_post_meta($variation_id, '_sku', true);
                                    if (!empty($sku)) {
                                        $fSKU = explode("__", str_replace("--", "__", $sku));
                                        $sSKU = explode("_", $fSKU[0]);
                                    } else {
                                        $sku = get_post_meta($item['product_id'], '_sku', true);
                                        $sSKU = explode("_", $sku);
                                    }
                                } else {
                                    $sku = get_post_meta($item['product_id'], '_sku', true);
                                    $sSKU = explode("_", $sku);
                                }

                                $data = array(
                                    "product_sku" => $sSKU[1]
                                );
                                $res_data = $this->execute_curl($data, 'browse_order');
                                if ($res_data['status'] == 'success' && $res_data['msg'] == "true") {
                                    $qty = wc_get_order_item_meta($item_id, '_qty', true);
                                    $custom_text = wc_get_order_item_meta($item_id, 'Custom Field', true);
                                    if (!empty(trim($custom_text))) {
                                        $order_data[$item['product_id']][] = array("product_id" => $item['product_id'], "variation_id" => $variation_id, "qty" => $qty, "is_browse" => 0, "custom_field" => trim($custom_text));
                                    } else {
                                        $order_data[$item['product_id']][] = array("product_id" => $item['product_id'], "variation_id" => $variation_id, "qty" => $qty, "is_browse" => 0);
                                    }
                                    $price  = $price + $item->get_total();
                                } else { //check code for swp product start
                           
                                    $firstword = explode("_",$sku);
                                    
                                    if( $firstword[0] == "SWP" ){
                                       
                                            $qty         = wc_get_order_item_meta($item_id, '_qty', true);
                                            $custom_text = wc_get_order_item_meta($item_id, 'Custom Field', true);
                                            if( empty($variation_id) ) {
                                                $variation_id = $item['product_id'];
                                            }
                                            if (!empty(trim($custom_text))) {
                                                $order_data[$item['product_id']][] = array("product_id" => $item['product_id'], "variation_id" => $variation_id, "qty" => $qty, "is_browse" => 0, "custom_field" => trim($custom_text));
                                            } else {
                                                $order_data[$item['product_id']][] = array("product_id" => $item['product_id'], "variation_id" => $variation_id, "qty" => $qty, "is_browse" => 0);
                                            }

                                            $price = $price + $item->get_total();
                                    }    
                                      
                                } //check code for swp product end
                            }
                        }
                        if (!empty($order_data)) {
                            $orderCollection = serialize($order_data);
                            $insertOrder     = $wpdb->insert(
                                $order_table,
                                array(
                                    'woo_order_ID'     => $order_id,
                                    'woo_order_data'   => $orderCollection,
                                    'woo_order_status' => $order_status,
                                    'woo_order_email'  => $billing_email,
                                    'woo_order_price'  => $total_price,
                                    'woo_shirtee_id'   => '',
                                    'woo_order_date'   => $date_created,
                                    'status'           => 0
                                )
                            );
                        }
                    }
                }
            }
        }

        public function check_curl()
        {
            if (!function_exists('curl_init')) {
                return false;
            }
            return true;
        }

        public function execute_curl($data, $access_key)
        {
            if (!function_exists('curl_init')) {
                $this->send_emails("<p>We founds that curl is not enabled in your side. Please contact side administrator to enable the service of curl.</p><p><strong>Site URL :: <a href='" . site_url() . "' target='_blank'>" . get_option("blogname") . "</a></strong></p>", strtoupper(str_replace("_", " ", $access_key)));
                return false;
            }

            $settings     = $this->shirtee_settings();
            $access_token = $this->shirtee_settings('access_token');
            $url          = defined('SHIRTEE_WEB_PATH') ? SHIRTEE_WEB_PATH : "https://apibridge.shirtee.cloud/woo_api/stage_check/fetch_data_newapp.php";

            if (isset($data['settings'])) {
                $settings = $data['settings'];
                unset($data['settings']);
            }

            $req_data = array(
                'data'             => array(
                    'settings'     => $settings,
                    'token'        => $access_token,
                    'access_key'   => $access_key,
                    'data'         => $data,
                    'site_url'     => rtrim(site_url(), "/")
                )
            );

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($req_data));
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            $response = curl_exec($ch);
            $data = json_decode($response, true);            
            if ($response === false) {
                $this->send_emails("<p>Could not get reply: ".curl_error($ch)."</p>", strtoupper(str_replace("_", " ", $access_key)));
                return false;
            } elseif (curl_errno($ch) !== 0) {
                $this->send_emails("<p>CURL error while connecting to : ".$url."</p><p>Error : ".curl_error($ch)."</p>", strtoupper(str_replace("_", " ", $access_key)));
                return false;
            }
            curl_close($ch);
            return json_decode($response, true);
        }

        public function send_emails($msg, $cron_name) 
        {
            $to        = "devitsolution19@gmail.com";
            $blogname  = get_option("blogname");
            $from      = "info@shirtee.com";
            $subject   = "Shirtee - {$blogname} Error in Cron Execution";
            $headers   = "Content-Type: text/html; charset=UTF-8";
            $headers  .= "Content-Transfer-Encoding: 8bit";
            $headers  .= "From: Shirtee {$from} \r\n";
            $message   = "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>
            <html xmlns='http://www.w3.org/1999/xhtml'>
                <head>
                    <meta http-equiv='content-type' content='text/html; charset=UTF-8'>
                    <title>Shirtee - {$blogname} Error in Cron Execution</title>
                    <meta name='viewport' content='width=device-width, initial-scale=1.0'>
                    <link href='https://fonts.googleapis.com/css?family=Open+Sans:300,400,600&amp;subset=latin-ext' rel='stylesheet'>
                    <style type='text/css'>
                        html,body{
                            background-color:#FFFFFF;
                            font-family:'Open Sans',sans-serif;
                            margin-top:15px;
                        }
                        table{
                            border-collapse:collapse;
                            border:0;
                            background-clip:padding-box;
                            border-spacing:0;
                        }
                        a{
                            color:#3398cc;
                            text-decoration:none;
                        }
                        .main-table{
                            border:0;
                            background-color:#FFFFFF;
                            width:100%;
                        }
                        .main-sub-table.content{
                            margin:0 auto;
                            border:0;
                            background-color:#FFFFFF;
                            border-collapse:collapse;
                            width:100%;
                            max-width:400px;
                        }
                        .main-sub-table tr.logo td{
                            padding:10px;
                        }
                        .main-sub-table tr.logo td p{
                            text-align:center;
                        }
                        .main-sub-table tr.logo td img{
                            display:inline-block;
                            height:auto;
                            width:35%;
                        }
                        .main-sub-table .second-row{
                            color:#111111;
                            display:block;
                            font-size:17px;
                            font-style:normal;
                            font-weight:500;
                            margin:20px 0;
                            text-align:left;
                            line-height:1.5;
                            letter-spacing:1px;
                        }
                        .main-sub-table .second-row .second-row-content{
                            margin-left:25%;
                            margin-top:20px;
                        }
                        .main-sub-table .second-row span{
                            color:#334dca;
                            font-weight:700;
                        }
                        .main-sub-table .second-row span a{
                            color:#334dca;
                        }
                        .footer-row td{
                            margin:0;
                            padding:0;
                            width:100% !important;
                            padding-top:39px;
                            padding-bottom:15px;
                        }
                        .footer-section{
                            border:0;
                        }
                        .footer-section p{
                            text-align:center;
                            color:#545454;
                            display:block;
                            font-size:16px;
                            line-height:1.5em;
                            font-style:normal;
                            font-weight:400;
                            letter-spacing:normal;
                            margin:0 0 15px;
                        }
                        .footer-section p img{
                            margin:0 auto;
                            display:inline-block;
                            width:30%;
                            height:auto;
                        }
                        .footer-section h6{
                            text-align:center;
                            color:#334dca;
                            display:block;
                            font-size:13px;
                            line-height:1.5em;
                            font-style:normal;
                            font-weight:400;
                            letter-spacing:1px;
                            margin:0;
                        }
                    </style>
                </head>
                <body>
                    <table class='main-table'>
                        <tr>
                            <td>
                                <table class='main-sub-table content'>
                                    <tr class='logo'>
                                        <td id='templateContainerHeader' valign='top' mc:edit='welcomeedit01'>
                                            <p>
                                                <img src='{SHIRTEE_ROOT_PATH}/assets/img/logo.png' alt='Shirtee'>
                                            </p>
                                        </td>
                                    </tr>
                                    <tr class='second-row'>
                                        <td>
                                            <p>Hello Admin,</p>
                                            <div class='second-row-content'>
                                                <p>Sorry to inform you that your cron for <b>{$cron_name}</b> wasn't run properly due to some reasons.</p>
                                                <strong>Issue :: {$msg}</strong>
                                                <p><strong>Site URL :: <a href='".site_url()."' target='_blank'>{$blogname}</a></strong></p>
                                            </div>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <table>
                                                <tr>
                                                    <td>Regards,</td>
                                                </tr>
                                                <tr>
                                                    <td style='padding-top:0;padding-bottom:0;padding-left:0;padding-right:7px;border-top:0;border-bottom:0;border-right:solid 3px #3398cc;'>
                                                        <img id='preview-image-url' src='{SHIRTEE_ROOT_PATH}/assets/img/logo.png
                                                         height='50' width='150' alt='Shirtee'>
                                                    </td>
                                                    <td style='padding-top:0;padding-bottom:0;padding-left:12px;padding-right:0;'>
                                                        <table cellpadding='0' cellspacing='0' border='0' style='background:none;border-width:0px;border:0px;margin:0;padding:0;'>
                                                            <tr>
                                                                <td colspan='2' style='padding-bottom:5px;color:#3398cc;font-size:18px;'>Shirtee Group</td>
                                                            </tr>
                                                            <tr>
                                                                <td width='20' style='vertical-align:top;width:20px;color:#3398cc;font-size:14px;'>w: </td>
                                                                <td style='vertical-align:top;color:#000000;font-size:14px;'><a target='_blank' href='http://www.shirtee.com' style='color:#1da1db;text-decoration:none;font-weight:normal;font-size:14px;'>www.shirtee.com</a></td>
                                                            </tr>
                                                            <tr>
                                                                <td width='20' style='vertical-align:top;width:20px;color:#3398cc;font-size:14px;'>E: </td>
                                                                <td style='vertical-align:top;color:#000000;font-size:14px;'><a href='mailto:info@shirtee.com' style='color:#1da1db;text-decoration:none;font-weight:normal;font-size:14px;'>info@shirtee.com</a></td>
                                                            </tr>
                                                        </table>
                                                    </td>
                                                </tr>
                                            </table>
                                        </td>
                                    </tr>
                                </table>
                            </td>
                        </tr>
                    </table>
                </body>
            </html>";
            mail($to, $subject, $message, $headers);
        }

        public function welcome_template($res_data){
            $user_name = isset($res_data['data']['firstname']) && !empty($res_data['data']['firstname']) ? $res_data['data']['firstname'] : '';

            if($res_data['status'] == 'success'){
                $html = "<table align='center' border='0' cellpadding='0' cellspacing='0' id='m_8394907314868491120bodyTable' width='100%' style='border-collapse:collapse;table-layout:auto;padding:0;background-color:#F0F3FA;height:100%;margin:0;width:100%; box-shadow: 0px 2px 20px rgba(0, 0, 0, 0.05); '>
    <tbody>
        <tr>
            <td align='center' id='m_8394907314868491120bodyCell' valign='top' style='border-collapse:collapse;table-layout:auto;padding-top:20px;padding-left:20px;padding-bottom:20px;padding-right:20px;border-top:0;height:100%;margin:0;width:100%; box-shadow: 0px 2px 20px rgba(0, 0, 0, 0.05); '>

                <div class='m_8394907314868491120templateContainer' style='border:0 none #aaa;background-color:#fff;border-radius:5px;display:table;max-width:600px; position: relative; '>
                    <div class='m_8394907314868491120templateContainerInner' style='padding:0'>
                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                            <tbody>
                                <tr>
                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                        <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120templateRow' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                            <tbody>
                                                <tr>
                                                    <td class='m_8394907314868491120rowContainer m_8394907314868491120kmFloatLeft' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:19px;padding-top:7px;padding-left:19px;padding-right:19px'>
                                                                                        <h1 style='color:#394E71;display:block;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:20px;font-style:normal;font-weight:bold;line-height:1;letter-spacing:0;margin:0;margin-top:25px;text-align:left;text-align:center'>
                                                                                            Congratulations, {$user_name}!
                                                                                            <br>
                                                                                        </h1>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:19px;padding-top:7px;padding-left:19px;padding-right:19px'>
                                                                                        <h1 style='max-width: 340px;color:#394E71;display:block;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:20px;font-style:normal;font-weight:bold;line-height:28px;letter-spacing:0;margin:0 auto;margin-top:25px;text-align:left;text-align:center'>
                                                                                            You successfully connected Woo &amp; Shirtee.Cloud.
                                                                                        </h1>
                                                                                    </td>
                                                                                    <tr>
                                                                                        <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:19px;padding-top:7px;padding-left:19px;padding-right:19px'>
                                                                                        <h1 style='max-width: 340px;color:#394E71;display:block;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:20px;font-style:normal;font-weight:bold;line-height:28px;letter-spacing:0;margin:0 auto;margin-top:25px;text-align:left;text-align:center'>
                                                                                            We are connected to shirtee products dashboard...
                                                                                        </h1>
                                                                                    </td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                                <tr>
                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                        <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120templateRow' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                            <tbody>
                                                <tr>
                                                    <td class='m_8394907314868491120rowContainer m_8394907314868491120kmFloatLeft' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                               
                                                                                
                                                                                                <tr>
                                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:13px;padding-bottom:50px;padding-left:35px;padding-right:27px; text-align: center;'>
                                                                                                    </td>
                                                                                                </tr>
                                                                                            </tbody>
                                                                                        </table>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>

                                                            <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmMobileOnly' width='100%' style='border-collapse:collapse;table-layout:fixed;min-width:100%'>
                                                                <tbody>
                                                                    <tr>
                                                                        <td style='border-collapse:collapse;table-layout:fixed;padding:9px;padding-top:4px;background-color:#fff;padding-bottom:30px' valign='top'>
                                                                            <table align='left' border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed;width:100%'>
                                                                                <tbody>
                                                                                    <tr>
                                                                                        <td class='m_8394907314868491120kmImageContent' valign='top' style='border-collapse:collapse;table-layout:fixed;padding:0;font-size:0;padding-top:0px;padding-bottom:50px;padding-left:9px;padding-right:9px;text-align:center'>
                                                                                            <a href='https://shirtee.cloud' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://shirtee.cloud'>
                                                                                                <img align='center'
                                                                                                    alt='Shirtee.cloud'
                                                                                                    class='m_8394907314868491120kmImage CToWUd'
                                                                                                    src='https://shopify-app.shirtee.cloud/admin/images/shirteecloud-logo.jpg'
                                                                                                    width='400'
                                                                                                    style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;padding-bottom:0;display:inline;vertical-align:top;font-size:12px;max-width:200px;padding:0;border-width:0'>
                                                                                            </a>
                                                                                        </td>
                                                                                    </tr>
                                                                                </tbody>
                                                                            </table>
                                                                            <table border='0' cellpadding='0' cellspacing='0' width='100%' align='center' style='border-collapse:collapse;border-spacing:0px;text-align:left!important; max-width: 500px;'>
                                                                                <tbody>
                                                                                    <tr>
                                                                                        <td width='20' bgcolor='#ffffff' style='font-size:0px;line-height:0px'>
                                                                                            &nbsp;</td>
                                                                                        <td height='1' bgcolor='#d1d1d1' style='font-size:0px;line-height:0px'>
                                                                                            &nbsp;</td>
                                                                                        <td width='20' bgcolor='#ffffff' style='font-size:0px;line-height:0px'>
                                                                                            &nbsp;</td>
                                                                                    </tr>
                                                                                </tbody>
                                                                            </table>
                                                                        </td>
                                                                    </tr>
                                                                </tbody>
                                                            </table>
                                                        </table>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' class='m_8394907314868491120kmDesktopOnly' style='border-collapse:collapse;table-layout:fixed;background-color:#fff'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmMobileStretch' style='border-collapse:collapse;table-layout:fixed;padding-top:0;padding-bottom:15px;padding-left:230px;padding-right:230px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed;'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td style='border-collapse:collapse;table-layout:fixed'>
                                                                                        <span></span></td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' class='m_8394907314868491120kmMobileOnly' style='border-collapse:collapse;table-layout:fixed;display:none;background-color:#fff'>
                                                            <tbody>
                                                                <tr>
                                                                    <td style='border-collapse:collapse;table-layout:fixed;padding-top:24px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td style='border-collapse:collapse;table-layout:fixed'>
                                                                                        <span></span></td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-top:0px;padding-bottom:4px;background-color:#fff;padding-left:9px;padding-right:9px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td align='center' style='border-collapse:collapse;table-layout:fixed;padding-left:9px;padding-right:9px'>
                                                                                        <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmButtonBarContent' style='border-collapse:collapse;table-layout:fixed;font-family:&quot;Helvetica Neue&quot;,Arial'>
                                                                                            <tbody>
                                                                                                <tr>
                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                        <table border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed;margin: 0 auto;'>
                                                                                                            <tbody>
                                                                                                                <tr>
                                                                                                                    <td valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:40px;padding-bottom:5px'>
                                                                                                                                        <a href='https://www.facebook.com/ShirteeCloud-879218089126863/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://www.facebook.com/ShirteeCloud-879218089126863/'><img
                                                                                                                                                src='https://shopify-app.shirtee.cloud/admin/images/icon-facebook.jpg'
                                                                                                                                                alt=''
                                                                                                                                                width='40'
                                                                                                                                                style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;width:40px;max-width:100%;display:block'
                                                                                                                                                class='CToWUd'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:10px;padding-bottom:9px'>
                                                                                                                                        <a href='https://www.facebook.com/ShirteeCloud-879218089126863/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none;color:#555555;font-family:Arial;font-size:14px;text-align:center;text-decoration:none' target='_blank' data-saferedirecturl='https://www.facebook.com/ShirteeCloud-879218089126863/'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>


                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td width='10' style='border-collapse:collapse;table-layout:fixed;width:10px'>
                                                                                                                                        &nbsp;
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>

                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:40px;padding-bottom:5px'>
                                                                                                                                        <a href='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw'><img
                                                                                                                                                src='https://shopify-app.shirtee.cloud/admin/images/icon-youtube.jpg'
                                                                                                                                                alt=''
                                                                                                                                                width='40'
                                                                                                                                                style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;width:40px;max-width:100%;display:block'
                                                                                                                                                class='CToWUd'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:10px;padding-bottom:9px'>
                                                                                                                                        <a href='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none;color:#555555;font-family:Arial;font-size:14px;text-align:center;text-decoration:none' target='_blank' data-saferedirecturl='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>

                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td width='10' style='border-collapse:collapse;table-layout:fixed;width:10px'>
                                                                                                                                        &nbsp;
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>


                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-bottom:5px'>
                                                                                                                                        <a href='https://www.instagram.com/shirteecloud.de/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://www.instagram.com/shirteecloud.de/'><img
                                                                                                                                                src='https://shopify-app.shirtee.cloud/admin/images/icon-insta.jpg'
                                                                                                                                                alt=''
                                                                                                                                                width='40'
                                                                                                                                                style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;width:40px;max-width:100%;display:block'
                                                                                                                                                class='CToWUd'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:10px;padding-bottom:9px'>
                                                                                                                                        <a href='https://www.instagram.com/shirteecloud.de/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none;color:#555555;font-family:Arial;font-size:14px;text-align:center;text-decoration:none' target='_blank' data-saferedirecturl='https://www.instagram.com/shirteecloud.de/'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>


                                                                                                                    </td>
                                                                                                                </tr>
                                                                                                            </tbody>
                                                                                                        </table>
                                                                                                    </td>
                                                                                                </tr>
                                                                                            </tbody>
                                                                                        </table>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' class='m_8394907314868491120kmDesktopOnly' style='border-collapse:collapse;table-layout:fixed;background-color:#fff'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmMobileStretch' style='border-collapse:collapse;table-layout:fixed;padding-top:2px;padding-bottom:16px;padding-left:200px;padding-right:200px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed;'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td style='border-collapse:collapse;table-layout:fixed'>
                                                                                        <span></span></td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed;background-color:#fff'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;font-size:14px;padding-bottom:40px;text-align:center;padding-right:18px;padding-left:18px;padding-top:0px'>
                                                                                        <p style='margin:0;padding-bottom:0;text-align:center;'>

                                                                                            <span style='text-align:center; vertical-align: sub;padding-right:10px;'><img
                                                                                                    src='https://shopify-app.shirtee.cloud/admin/images/icon-heart.jpg'
                                                                                                    alt=''
                                                                                                    style='width:18px;'></span><span style='text-align:center;color:#394E71'>Printed
                                                                                                in Cologne with
                                                                                                Love</span>
                                                                                        </p>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                            </tbody>
                        </table>

                    </div>
                </div>
            </td>
        </tr>
    </tbody>
</table>

";
                echo $html;
            } else {
                $html_error = "<table align='center' border='0' cellpadding='0' cellspacing='0' id='m_8394907314868491120bodyTable' width='100%' style='border-collapse:collapse;table-layout:auto;padding:0;background-color:#F0F3FA;height:100%;margin:0;width:100%; box-shadow: 0px 2px 20px rgba(0, 0, 0, 0.05); '>
    <tbody>
        <tr>
            <td align='center' id='m_8394907314868491120bodyCell' valign='top' style='border-collapse:collapse;table-layout:auto;padding-top:20px;padding-left:20px;padding-bottom:20px;padding-right:20px;border-top:0;height:100%;margin:0;width:100%; box-shadow: 0px 2px 20px rgba(0, 0, 0, 0.05); '>

                <div class='m_8394907314868491120templateContainer' style='border:0 none #aaa;background-color:#fff;border-radius:5px;display:table;max-width:600px; position: relative; '>
                    <div class='m_8394907314868491120templateContainerInner' style='padding:0'>
                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                            <tbody>
                                <tr>
                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                        <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120templateRow' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                            <tbody>
                                                <tr>
                                                    <td class='m_8394907314868491120rowContainer m_8394907314868491120kmFloatLeft' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:19px;padding-top:7px;padding-left:19px;padding-right:19px'>
                                                                                        <h1 style='color:#394E71;display:block;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:20px;font-style:normal;font-weight:bold;line-height:1;letter-spacing:0;margin:0;margin-top:25px;text-align:left;text-align:center'>
                                                                                            Sorry, {$user_name}!
                                                                                            <br>
                                                                                        </h1>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:19px;padding-top:7px;padding-left:19px;padding-right:19px'>
                                                                                        <h1 style='max-width: 340px;color:#394E71;display:block;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:20px;font-style:normal;font-weight:bold;line-height:28px;letter-spacing:0;margin:0 auto;margin-top:25px;text-align:left;text-align:center'>
                                                                                            Your Email Address Already Verified...
                                                                                        </h1>
                                                                                    </td>
                                                                                    <tr>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                                <tr>
                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                        <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120templateRow' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                            <tbody>
                                                <tr>
                                                    <td class='m_8394907314868491120rowContainer m_8394907314868491120kmFloatLeft' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                               
                                                                                
                                                                                                <tr>
                                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;padding-top:13px;padding-bottom:50px;padding-left:35px;padding-right:27px; text-align: center;'>
                                                                                                    </td>
                                                                                                </tr>
                                                                                            </tbody>
                                                                                        </table>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>

                                                            <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmMobileOnly' width='100%' style='border-collapse:collapse;table-layout:fixed;min-width:100%'>
                                                                <tbody>
                                                                    <tr>
                                                                        <td style='border-collapse:collapse;table-layout:fixed;padding:9px;padding-top:4px;background-color:#fff;padding-bottom:30px' valign='top'>
                                                                            <table align='left' border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed;width:100%'>
                                                                                <tbody>
                                                                                    <tr>
                                                                                        <td class='m_8394907314868491120kmImageContent' valign='top' style='border-collapse:collapse;table-layout:fixed;padding:0;font-size:0;padding-top:0px;padding-bottom:50px;padding-left:9px;padding-right:9px;text-align:center'>
                                                                                            <a href='https://shirtee.cloud' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://shirtee.cloud'>
                                                                                                <img align='center'
                                                                                                    alt='Shirtee.cloud'
                                                                                                    class='m_8394907314868491120kmImage CToWUd'
                                                                                                    src='https://shopify-app.shirtee.cloud/admin/images/shirteecloud-logo.jpg'
                                                                                                    width='400'
                                                                                                    style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;padding-bottom:0;display:inline;vertical-align:top;font-size:12px;max-width:200px;padding:0;border-width:0'>
                                                                                            </a>
                                                                                        </td>
                                                                                    </tr>
                                                                                </tbody>
                                                                            </table>
                                                                            <table border='0' cellpadding='0' cellspacing='0' width='100%' align='center' style='border-collapse:collapse;border-spacing:0px;text-align:left!important; max-width: 500px;'>
                                                                                <tbody>
                                                                                    <tr>
                                                                                        <td width='20' bgcolor='#ffffff' style='font-size:0px;line-height:0px'>
                                                                                            &nbsp;</td>
                                                                                        <td height='1' bgcolor='#d1d1d1' style='font-size:0px;line-height:0px'>
                                                                                            &nbsp;</td>
                                                                                        <td width='20' bgcolor='#ffffff' style='font-size:0px;line-height:0px'>
                                                                                            &nbsp;</td>
                                                                                    </tr>
                                                                                </tbody>
                                                                            </table>
                                                                        </td>
                                                                    </tr>
                                                                </tbody>
                                                            </table>
                                                        </table>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' class='m_8394907314868491120kmDesktopOnly' style='border-collapse:collapse;table-layout:fixed;background-color:#fff'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmMobileStretch' style='border-collapse:collapse;table-layout:fixed;padding-top:0;padding-bottom:15px;padding-left:230px;padding-right:230px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed;'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td style='border-collapse:collapse;table-layout:fixed'>
                                                                                        <span></span></td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' class='m_8394907314868491120kmMobileOnly' style='border-collapse:collapse;table-layout:fixed;display:none;background-color:#fff'>
                                                            <tbody>
                                                                <tr>
                                                                    <td style='border-collapse:collapse;table-layout:fixed;padding-top:24px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td style='border-collapse:collapse;table-layout:fixed'>
                                                                                        <span></span></td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-top:0px;padding-bottom:4px;background-color:#fff;padding-left:9px;padding-right:9px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td align='center' style='border-collapse:collapse;table-layout:fixed;padding-left:9px;padding-right:9px'>
                                                                                        <table border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmButtonBarContent' style='border-collapse:collapse;table-layout:fixed;font-family:&quot;Helvetica Neue&quot;,Arial'>
                                                                                            <tbody>
                                                                                                <tr>
                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                        <table border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed;margin: 0 auto;'>
                                                                                                            <tbody>
                                                                                                                <tr>
                                                                                                                    <td valign='top' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:40px;padding-bottom:5px'>
                                                                                                                                        <a href='https://www.facebook.com/ShirteeCloud-879218089126863/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://www.facebook.com/ShirteeCloud-879218089126863/'><img
                                                                                                                                                src='https://shopify-app.shirtee.cloud/admin/images/icon-facebook.jpg'
                                                                                                                                                alt=''
                                                                                                                                                width='40'
                                                                                                                                                style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;width:40px;max-width:100%;display:block'
                                                                                                                                                class='CToWUd'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:10px;padding-bottom:9px'>
                                                                                                                                        <a href='https://www.facebook.com/ShirteeCloud-879218089126863/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none;color:#555555;font-family:Arial;font-size:14px;text-align:center;text-decoration:none' target='_blank' data-saferedirecturl='https://www.facebook.com/ShirteeCloud-879218089126863/'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>


                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td width='10' style='border-collapse:collapse;table-layout:fixed;width:10px'>
                                                                                                                                        &nbsp;
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>

                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:40px;padding-bottom:5px'>
                                                                                                                                        <a href='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw'><img
                                                                                                                                                src='https://shopify-app.shirtee.cloud/admin/images/icon-youtube.jpg'
                                                                                                                                                alt=''
                                                                                                                                                width='40'
                                                                                                                                                style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;width:40px;max-width:100%;display:block'
                                                                                                                                                class='CToWUd'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:10px;padding-bottom:9px'>
                                                                                                                                        <a href='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none;color:#555555;font-family:Arial;font-size:14px;text-align:center;text-decoration:none' target='_blank' data-saferedirecturl='https://www.youtube.com/channel/UCMngeJszAvtvIEYoAk-z4pw'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>

                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td width='10' style='border-collapse:collapse;table-layout:fixed;width:10px'>
                                                                                                                                        &nbsp;
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>


                                                                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' style='border-collapse:collapse;table-layout:fixed'>
                                                                                                                            <tbody>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-bottom:5px'>
                                                                                                                                        <a href='https://www.instagram.com/shirteecloud.de/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none' target='_blank' data-saferedirecturl='https://www.instagram.com/shirteecloud.de/'><img
                                                                                                                                                src='https://shopify-app.shirtee.cloud/admin/images/icon-insta.jpg'
                                                                                                                                                alt=''
                                                                                                                                                width='40'
                                                                                                                                                style='border:0;height:auto;line-height:100%;outline:none;text-decoration:none;max-width:100%;width:40px;max-width:100%;display:block'
                                                                                                                                                class='CToWUd'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                                <tr>
                                                                                                                                    <td align='center' valign='top' style='border-collapse:collapse;table-layout:fixed;padding-right:10px;padding-bottom:9px'>
                                                                                                                                        <a href='https://www.instagram.com/shirteecloud.de/' style='word-wrap:break-word;max-width:100%;color:#f0473d;font-weight:normal;text-decoration:none;color:#555555;font-family:Arial;font-size:14px;text-align:center;text-decoration:none' target='_blank' data-saferedirecturl='https://www.instagram.com/shirteecloud.de/'></a>
                                                                                                                                    </td>
                                                                                                                                </tr>
                                                                                                                            </tbody>
                                                                                                                        </table>


                                                                                                                    </td>
                                                                                                                </tr>
                                                                                                            </tbody>
                                                                                                        </table>
                                                                                                    </td>
                                                                                                </tr>
                                                                                            </tbody>
                                                                                        </table>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>

                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' class='m_8394907314868491120kmDesktopOnly' style='border-collapse:collapse;table-layout:fixed;background-color:#fff'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmMobileStretch' style='border-collapse:collapse;table-layout:fixed;padding-top:2px;padding-bottom:16px;padding-left:200px;padding-right:200px'>
                                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed;'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td style='border-collapse:collapse;table-layout:fixed'>
                                                                                        <span></span></td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>
                                                        <table border='0' cellpadding='0' cellspacing='0' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                            <tbody>
                                                                <tr>
                                                                    <td class='m_8394907314868491120kmTextBlockInner' valign='top' style='border-collapse:collapse;table-layout:fixed;background-color:#fff'>
                                                                        <table align='left' border='0' cellpadding='0' cellspacing='0' class='m_8394907314868491120kmTextContentContainer' width='100%' style='border-collapse:collapse;table-layout:fixed'>
                                                                            <tbody>
                                                                                <tr>
                                                                                    <td class='m_8394907314868491120kmTextContent' valign='top' style='border-collapse:collapse;table-layout:fixed;color:#555;font-family:&quot;Helvetica Neue&quot;,Arial;font-size:16px;line-height:1.5;letter-spacing:0;text-align:left;max-width:100%;word-wrap:break-word;font-size:14px;padding-bottom:40px;text-align:center;padding-right:18px;padding-left:18px;padding-top:0px'>
                                                                                        <p style='margin:0;padding-bottom:0;text-align:center;'>

                                                                                            <span style='text-align:center; vertical-align: sub;padding-right:10px;'><img
                                                                                                    src='https://shopify-app.shirtee.cloud/admin/images/icon-heart.jpg'
                                                                                                    alt=''
                                                                                                    style='width:18px;'></span><span style='text-align:center;color:#394E71'>Printed
                                                                                                in Cologne with
                                                                                                Love</span>
                                                                                        </p>
                                                                                    </td>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </tbody>
                                                        </table>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
            </td>
        </tr>
    </tbody>
</table>";
        echo $html_error;
            }        
        }    
    }    
}?>